@@ -14,8 +14,9 @@
 #include "odemilbutton.h"
 #include "odscrolledbox.h"
 
-#include "strutil.h"
 #include "cmdseq.h"
+#include "menus.h"
+#include "strutil.h"
 #include "xmlutil.h"
 #include "buttons.h"
 
@@ -38,6 +39,7 @@ struct Button {				/* A run-time button definition, as stored in button banks. *
 	GString	*cmdseq[BTN_FACES];			/* Command sequence to run when clicked. */
 	gchar	key[BTN_FACES][KEY_NAME_SIZE];		/* Keyboard shortcut. */
 	BColor	color[BTN_FACES][2];			/* Back- and fore colors for each face. */
+	gchar	menu[MNU_MENU_NAME_SIZE];		/* Name of menu bound to this button. */
 	gchar	tooltip[BTN_TOOLTIP_SIZE];		/* Tooltip (help text) for this button. */
 	guint32	flags;					/* Various flags. See BTF_XXX defines in header. */
 };
@@ -62,12 +64,12 @@ static gboolean	button_set_face(GtkWidget *widget, BtnFace face);
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-09-15 -	Set the given <bti> to the default (built-in) buttons. */
-void btn_buttoninfo_default(MainInfo *min, ButtonInfo *bti)
+void btn_buttoninfo_new_default(MainInfo *min, ButtonInfo *bti)
 {
 	ButtonSheet	*bsh;
 
 	bti->sheets = NULL;
-	if((bsh = btn_buttonsheet_default(min)) != NULL)
+	if((bsh = btn_buttonsheet_new_default(min)) != NULL)
 		bti->sheets = g_list_append(bti->sheets, bsh);
 }
 
@@ -201,10 +203,10 @@ void btn_buttoninfo_save(MainInfo *min, ButtonInfo *bti, FILE *out, const gchar
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-01 -	Load the face definitions for a given button. */
-static void load_button_faces(XmlNode *node, gpointer button)
+static void load_button_faces(const XmlNode *node, gpointer button)
 {
 	Button		*btn = button;	/* Saves a few casts. */
-	gchar		*str;
+	const gchar	*str;
 	guint		face;
 	GdkColor	tmp_c;
 
@@ -227,11 +229,11 @@ static void load_button_faces(XmlNode *node, gpointer button)
 **		live up to now.
 ** FIXMEFIXME -	This function contains backwards-compatibility. Yuck. Remove later.
 */
-static void load_button(XmlNode *node, gpointer r)
+static void load_button(const XmlNode *node, gpointer r)
 {
 	ButtonRow	*brw = (ButtonRow *) r;
 	Button		*btn;
-	gchar		*str;
+	const gchar	*str;
 	gint		pos;
 	guint		pos2;
 
@@ -257,8 +259,8 @@ static void load_button(XmlNode *node, gpointer r)
 	}
 	else if(xml_get_uinteger(node, "pos", &pos2))	/* If position is unsigned (more logical), we're modern. */
 	{
-		guint	tmpu;
-		XmlNode	*bfaces;
+		guint		tmpu;
+		const XmlNode	*bfaces;
 
 		btn = brw->button + pos2;
 
@@ -272,11 +274,11 @@ static void load_button(XmlNode *node, gpointer r)
 	}
 }
 
-static void load_row(XmlNode *node, gpointer s)
+static void load_row(const XmlNode *node, gpointer s)
 {
 	ButtonSheet	*bsh = (ButtonSheet *) s;
 	ButtonRow	*brw;
-	XmlNode		*data;
+	const XmlNode	*data;
 	gint		width;
 
 	if(xml_get_integer(node, "width", &width))
@@ -295,11 +297,11 @@ static void load_row(XmlNode *node, gpointer s)
 	}
 }
 
-static void load_sheet(XmlNode *node, gpointer m)
+static void load_sheet(const XmlNode *node, gpointer m)
 {
 	MainInfo	*min = (MainInfo *) m;
 	ButtonSheet	*bsh;
-	XmlNode		*data;
+	const XmlNode	*data;
 
 	if((bsh = btn_buttonsheet_new(NULL)) != NULL)
 	{
@@ -310,7 +312,7 @@ static void load_sheet(XmlNode *node, gpointer m)
 	}
 }
 
-void btn_buttoninfo_load(MainInfo *min, ButtonInfo *bti, XmlNode *node)
+void btn_buttoninfo_load(MainInfo *min, ButtonInfo *bti, const XmlNode *node)
 {
 	btn_buttoninfo_destroy(bti);
 	xml_node_visit_children(node, load_sheet, min);
@@ -341,6 +343,7 @@ Button * btn_button_new(Button *base, guint num)
 				base[i].color[j][0].valid = FALSE;
 				base[i].color[j][1].valid = FALSE;
 			}
+			base[i].menu[0] = '\0';
 			base[i].tooltip[0] = '\0';
 			base[i].flags = 0U;
 		}
@@ -348,18 +351,6 @@ Button * btn_button_new(Button *base, guint num)
 	return base;
 }
 
-/* 1998-09-15 -	Initialize a (previously allocated with new() above) button with <label> and <cmd>. */
-void btn_button_init(Button *btn, const gchar *label, const gchar *cmd, const gchar *key)
-{
-	if(btn != NULL)
-	{
-		btn_button_clear(btn);	/* Take no chances. */
-		btn_button_set_label(btn, BTN_PRIMARY, label);
-		btn_button_set_cmdseq(btn, BTN_PRIMARY, cmd);
-		btn_button_set_key(btn, BTN_PRIMARY, key);
-	}
-}
-
 /* 1999-03-31 -	Set the label of a button. */
 void btn_button_set_label(Button *btn, BtnFace face, const gchar *label)
 {
@@ -491,6 +482,43 @@ void btn_button_set_color_fg_widget(GtkWidget *widget, BtnFace face, const GdkCo
 	}
 }
 
+/* 2000-12-11 -	Set the menu for a button. */
+void btn_button_set_menu(Button *btn, const gchar *name)
+{
+	if(btn != NULL)
+		stu_strncpy(btn->menu, name, sizeof btn->menu);
+}
+
+void btn_button_set_menu_widget(GtkWidget *wid, const gchar *menu)
+{
+	Button	*btn = btn_button_get(wid);
+
+	if(btn != NULL)
+	{
+		od_emil_button_remove_menu(OD_EMIL_BUTTON(wid));
+		if(menu == NULL || *menu == '\0')	/* Remove? */
+			btn_button_set_menu(btn, "");
+		else
+		{
+			MainInfo	*min;
+			GtkWidget	*m;
+
+			btn_button_set_menu(btn, menu);
+			min = gtk_object_get_data(GTK_OBJECT(wid), "min");
+			if((m = mnu_menu_widget_get(min->cfg.menus, menu)) != NULL)
+				od_emil_button_set_menu(OD_EMIL_BUTTON(wid), GTK_MENU(m));
+		}
+	}
+}
+
+/* 2000-12-11 -	Return the menu for a button. */
+const gchar * btn_button_get_menu(const Button *btn)
+{
+	if(btn != NULL)
+		return btn->menu;
+	return NULL;
+}
+
 /* 1999-05-01 -	Get the definition from an instantiated widget. */
 Button * btn_button_get(GtkWidget *wid)
 {
@@ -556,7 +584,6 @@ gboolean btn_button_get_color_fg(Button *btn, BtnFace face, GdkColor *fg)
 	return FALSE;
 }
 
-
 /* 1999-01-13 -	Just install a tooltip string. Really simple. */
 void btn_button_set_tooltip(Button *btn, const gchar *tip)
 {
@@ -641,6 +668,7 @@ void btn_button_clear(Button *btn)
 		btn->color[i][0].valid = FALSE;		/* Invalidate back- and foreground colors. */
 		btn->color[i][1].valid = FALSE;
 	}
+	btn_button_set_menu(btn, "");
 	btn_button_set_tooltip(btn, NULL);
 	btn->flags = 0U;
 }
@@ -670,6 +698,7 @@ void btn_button_copy(Button *dst, Button *src)
 			dst->color[i][0] = src->color[i][0];
 			dst->color[i][1] = src->color[i][1];
 		}
+		stu_strncpy(dst->menu, src->menu, sizeof dst->menu);
 		stu_strncpy(dst->tooltip, src->tooltip, sizeof dst->tooltip);
 		dst->flags = src->flags;
 	}
@@ -732,7 +761,22 @@ static gboolean button_set_face(GtkWidget *widget, BtnFace face)
 			if(btn_button_get_color_fg(btn, face, &buf[1]))
 				fg = &buf[1];
 			od_emil_button_set_label(OD_EMIL_BUTTON(widget), face, (gchar *) lab, fg, bg, NULL);
-			ret = TRUE;
+
+			/* Experiment with icons in buttons. */
+/*			{
+				GtkWidget	*hbox, *label, *icon;
+				GdkPixmap	*pmap;
+				GdkBitmap	*mask;
+
+				hbox = gtk_hbox_new(FALSE, 0);
+				pmap = gdk_pixmap_colormap_create_from_xpm(NULL, gtk_widget_get_default_colormap(), &mask, NULL, "/home/emil/data/projects/gentoo-0.11.17/icons/Image.xpm");
+				icon = gtk_pixmap_new(pmap, mask);
+				gtk_box_pack_start(GTK_BOX(hbox), icon, FALSE, FALSE, 0);
+				label = gtk_label_new(lab);
+				gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
+				od_emil_button_set_widget(OD_EMIL_BUTTON(widget), face, hbox, NULL);
+			}
+*/			ret = TRUE;
 		}
 		gtk_widget_queue_draw(widget);
 	}
@@ -750,6 +794,7 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 	if((but = od_emil_button_new()) != NULL)
 	{
 		gboolean	set = FALSE;
+		const gchar	*mn;
 		BtnFace		i;
 
 		GTK_WIDGET_UNSET_FLAGS(but, GTK_CAN_FOCUS);
@@ -759,6 +804,16 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 
 		for(i = 0; i < BTN_FACES; i++)
 			set |= button_set_face(but, i);
+		if((mn = btn_button_get_menu(btn)) != NULL)
+		{
+			GtkWidget	*menu;
+
+			if((menu = mnu_menu_widget_get(min->cfg.menus, mn)) != NULL)
+			{
+				fprintf(stderr, "Attaching menu \"%s\" to button \"%s\"\n", mn, btn_button_get_label(btn, 0));
+				od_emil_button_set_menu(OD_EMIL_BUTTON(but), GTK_MENU(menu));
+			}
+		}
 		gtk_signal_connect(GTK_OBJECT(but), "activate", GTK_SIGNAL_FUNC(func), user);
 		if(partial)
 			od_emil_button_config_mode(OD_EMIL_BUTTON(but), TRUE);
@@ -795,7 +850,7 @@ static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean parti
 {
 	GtkWidget	*hbox, *hbox2 = NULL, *btn;
 	GtkTooltips	*tt = NULL;
-	guint		i, keep_tt = 0;
+	guint		i, keep_tt = 0U;
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	if(!partial)
@@ -837,7 +892,6 @@ static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean parti
 		}
 		gtk_widget_show(hbox2);
 	}
-
 	if(keep_tt)
 		gtk_signal_connect(GTK_OBJECT(hbox), "destroy", GTK_SIGNAL_FUNC(evt_brow_destroy), (gpointer) tt);
 	else if(tt != NULL)
@@ -863,7 +917,7 @@ ButtonRow * btn_buttonrow_new(gint width)
 #define	DEF_WIDTH	(8)
 
 /* 1998-09-15 -	Build the default button row. Just a few very basic functions. */
-ButtonRow * btn_buttonrow_default(MainInfo *min)
+ButtonRow * btn_buttonrow_new_default(MainInfo *min)
 {
 	ButtonRow	*brw;
 	const gchar	*lab[BTN_FACES * DEF_WIDTH] =
@@ -987,7 +1041,7 @@ ButtonSheet * btn_buttonsheet_new(const gchar *label)
 /* 1998-09-15 -	Build the default button sheet, and return it.
 ** 1999-01-05 -	Fixed a *huge* bug, where the same row was added twice to the list!!
 */
-ButtonSheet * btn_buttonsheet_default(MainInfo *min)
+ButtonSheet * btn_buttonsheet_new_default(MainInfo *min)
 {
 	ButtonSheet	*bsh;
 	ButtonRow	*brw;
@@ -996,7 +1050,7 @@ ButtonSheet * btn_buttonsheet_default(MainInfo *min)
 	{
 		stu_strncpy(bsh->label, BTN_DEFAULT_SHEET, sizeof bsh->label);
 		bsh->rows = NULL;
-		if((brw = btn_buttonrow_default(min)) != NULL)
+		if((brw = btn_buttonrow_new_default(min)) != NULL)
 			btn_buttonsheet_append_row(bsh, brw);
 		if((brw = btn_buttonrow_new(8)) != NULL)
 			btn_buttonsheet_append_row(bsh, brw);
@@ -1072,7 +1126,7 @@ void btn_buttonsheet_delete_row(ButtonSheet *bsh, ButtonRow *brw)
 /* 1998-09-19 -	Move the row <brw> up (delta == -1) or down (delta == 1) in the sheet <bsh>.
 **		The rows will "wrap" around at top and bottom of the sheet.
 */
-void btn_buttonsheet_move_row(ButtonSheet *bsh, ButtonRow *brw, int delta)
+void btn_buttonsheet_move_row(ButtonSheet *bsh, ButtonRow *brw, gint delta)
 {
 	GList	*link;
 	gint	pos, np;
@@ -1097,7 +1151,7 @@ guint btn_buttonsheet_get_height(ButtonSheet *bsh)
 }
 
 /* 1998-09-15 -	Return pointer to sheet labeled <label>. */
-ButtonSheet * btn_buttonsheet_get(ButtonInfo *bti, char *label)
+ButtonSheet * btn_buttonsheet_get(ButtonInfo *bti, const gchar *label)
 {
 	GList	*iter;
 
@@ -1128,13 +1182,10 @@ static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean p
 	for(iter = bsh->rows; iter != NULL; iter = g_list_next(iter))
 	{
 		if((row = buttonrow_build(min, (ButtonRow *) iter->data, partial, func, user)) != NULL)
-		{
 			gtk_box_pack_start(GTK_BOX(vbox), row, FALSE, FALSE, 0);
-			gtk_widget_show(row);
-		}
 	}
 	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scbox), vbox);
-	gtk_widget_show(vbox);
+	gtk_widget_show_all(vbox);
 
 	return scbox;
 }
