@@ -26,6 +26,7 @@
 #include "cfg_module.h"
 #include "cfg_cmdseq.h"
 
+#include "cfg_menus.h"
 #include "cfg_buttons.h"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -55,9 +56,11 @@ struct P_Buttons {
 	GtkWidget	*dvbox;			/* All definitions. */
 	GtkWidget	*dhbox;			/* Actual function definitions (primary/secondary frames). */
 	BDef		def[2];			/* Primary & secondary face definitions. */
+	GtkWidget	*dmenu;			/* Entry for menu name. */
+	guint		dmenusig;		/* Signal for "changed" event. */
 	GtkWidget	*dtooltip;		/* String widget for tooltip. */
 	GtkWidget	*dnarrow;		/* A check button for the narrow-flag. */
-	gint		dnarsig;		/* Signal identifer for the narrow flag. */
+	guint		dnarsig;		/* Signal identifer for the narrow flag. */
 	GtkWidget	*dshowtip;		/* Check button for "Show Tooltip?". */
 
 	GtkWidget	*bcmd[4];		/* Button commands ("Edit", "Copy" etc.). */
@@ -119,6 +122,7 @@ static void reset_widgets(P_Buttons *page)
 		set_blocked_entry(page->def[i].cmdseq, "", page->def[i].cmdseq_sig);
 		gtk_entry_set_text(GTK_ENTRY(page->def[i].key), "");
 	}
+	set_blocked_entry(page->dmenu, "", page->dmenusig);
 	gtk_entry_set_text(GTK_ENTRY(page->dtooltip), "");
 	gtk_signal_handler_block(GTK_OBJECT(page->dnarrow), page->dnarsig);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dnarrow), FALSE);
@@ -148,6 +152,7 @@ static void set_widgets(P_Buttons *page)
 			set_blocked_entry(page->def[i].cmdseq, btn_button_get_cmdseq(but, i), page->def[i].cmdseq_sig);
 			set_blocked_entry(page->def[i].key, btn_button_get_key(but, i), 0);
 		}
+		set_blocked_entry(page->dmenu, btn_button_get_menu(but), page->dmenusig);
 		if((str = btn_button_get_tooltip(but)) != NULL)
 			gtk_entry_set_text(GTK_ENTRY(page->dtooltip), str);
 		else
@@ -664,6 +669,26 @@ static void evt_col_fg_clicked(GtkWidget *wid, gpointer wuser, guint function, g
 	}
 }
 
+static void evt_menu_changed(GtkWidget *wid, gpointer user)
+{
+	P_Buttons	*page = user;
+
+	if((page != NULL) && (page->button != NULL))
+	{
+		btn_button_set_menu_widget(page->button, gtk_entry_get_text(GTK_ENTRY(wid)));
+		page->modified = TRUE;
+	}
+}
+
+static void evt_menu_pick_clicked(GtkWidget *wid, gpointer user)
+{
+	P_Buttons	*page = user;
+	const gchar	*menu;
+
+	if((menu = mnu_menuinfo_select(cmu_get_menuinfo())) != NULL)
+		gtk_entry_set_text(GTK_ENTRY(page->dmenu), menu);
+}
+
 /* 1999-04-24 -	Initialize widgetry for a button definition box. Thanks to the new wonderful
 **		widget (contributed by J. Hanson <johan@tiq.com>) we now have two actions per
 **		button. Very Opus-ish, and very good.
@@ -736,6 +761,31 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 	gtk_widget_show(table);
 }
 
+static GtkWidget * init_mdef(MainInfo *min, P_Buttons *page)
+{
+	GtkWidget	*frame;
+	GtkWidget	*table, *label, *btn;
+
+	frame = gtk_frame_new(_("Menu"));
+	table = gtk_table_new(1, 3, FALSE);
+
+	label = gtk_label_new(_("Menu"));
+	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
+	page->dmenu = gtk_entry_new();
+	gtk_entry_set_editable(GTK_ENTRY(page->dmenu), FALSE);
+	page->dmenusig = gtk_signal_connect(GTK_OBJECT(page->dmenu), "changed", GTK_SIGNAL_FUNC(evt_menu_changed), page);
+	gtk_table_attach(GTK_TABLE(table), page->dmenu, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
+
+	btn = gui_details_button_new(min->gui->window->window);
+	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_menu_pick_clicked), page);
+
+	gtk_table_attach(GTK_TABLE(table), btn, 2, 3, 0, 1,  0,0,0,0);
+
+	gtk_container_add(GTK_CONTAINER(frame), table);
+
+	return frame;
+}
+
 static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 {
 	P_Buttons	*page = &the_page;
@@ -774,6 +824,10 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 	gtk_box_pack_start(GTK_BOX(page->dvbox), page->dhbox, TRUE, TRUE, 0);
 	gtk_widget_show(page->dhbox);
 
+	frame = init_mdef(min, page);
+	gtk_box_pack_start(GTK_BOX(page->dvbox), frame, TRUE, TRUE, 0);
+/*	gtk_widget_show_all(frame);*/
+
 	hbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Tooltip"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -883,7 +937,7 @@ static gint cbt_save(MainInfo *min, FILE *out)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-09-15 -	Load a bunch of button sheets in. */
-static void cbt_load(MainInfo *min, XmlNode *node)
+static void cbt_load(MainInfo *min, const XmlNode *node)
 {
 	btn_buttoninfo_load(min, &min->cfg.buttons, node);
 }
