@@ -1153,7 +1153,7 @@ static gint ccs_save(MainInfo *min, FILE *out)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-09-27 -	Load extra data for external command. */
-static void load_external(CX_Ext *cext, XmlNode *node)
+static void load_external(CX_Ext *cext, const XmlNode *node)
 {
 	xml_get_integer(node, "gflags", (gint *) &cext->gflags);
 	xml_get_integer(node, "bflags", (gint *) &cext->baflags[0]);
@@ -1161,14 +1161,14 @@ static void load_external(CX_Ext *cext, XmlNode *node)
 }
 
 /* 1998-09-27 -	Load a single command sequence row. */
-static void load_cmdrow(XmlNode *node, gpointer user)
+static void load_cmdrow(const XmlNode *node, gpointer user)
 {
-	CmdSeq	*cs = (CmdSeq *) user;
-	CmdRow	*row;
-	XmlNode	*data;
-	CRType	type = CRTP_BUILTIN;
-	gchar	*def = NULL, *tname = NULL;
-	guint32	flags = 0UL;
+	CmdSeq		*cs = (CmdSeq *) user;
+	CmdRow		*row;
+	const XmlNode	*data;
+	CRType		type = CRTP_BUILTIN;
+	const gchar	*def = NULL, *tname = NULL;
+	guint32		flags = 0UL;
 
 	if(xml_get_text(node, "type", &tname))
 		type = csq_cmdrow_string_to_type(tname);
@@ -1184,19 +1184,19 @@ static void load_cmdrow(XmlNode *node, gpointer user)
 }
 
 /* 1998-09-27 -	Trampoline. */
-static void load_cmdseq_rows(XmlNode *node, CmdSeq *cs)
+static void load_cmdseq_rows(const XmlNode *node, CmdSeq *cs)
 {
 	xml_node_visit_children(node, load_cmdrow, (gpointer) cs);
 }
 
 /* 1998-09-27 -	Load a command sequence. */
-static void load_cmdseq(XmlNode *node, gpointer user)
+static void load_cmdseq(const XmlNode *node, gpointer user)
 {
 	MainInfo	*min = (MainInfo *) user;
-	gchar		*name = "Unknown";
+	const gchar	*name = "Unknown";
 	guint32		flags = 0UL;
 	CmdSeq		*cs;
-	XmlNode		*data;
+	const XmlNode	*data;
 
 	xml_get_text(node, "name", &name);
 	xml_get_integer(node, "flags", (gint *) &flags);
@@ -1209,7 +1209,7 @@ static void load_cmdseq(XmlNode *node, gpointer user)
 }
 
 /* 1998-09-27 -	Load a tree full of command sequence data. */
-static void ccs_load(MainInfo *min, XmlNode *node)
+static void ccs_load(MainInfo *min, const XmlNode *node)
 {
 	/* First destroy any existing commands. */
 	if(min->cfg.commands.cmdseq != NULL)
