@@ -694,42 +694,42 @@ static gint cct_save(MainInfo *min, FILE *out)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-03-17 -	Load in and install a single key mapping. */
-static void key_load(XmlNode *node, gpointer user)
+static void key_load(const XmlNode *node, gpointer user)
 {
-	gchar	*name, *cmd;
+	const gchar	*name, *cmd;
 
 	if(xml_get_text(node, "keyname", &name) && xml_get_text(node, "cmdseq", &cmd))
 		ctrl_key_add(((MainInfo *) user)->cfg.ctrlinfo, name, csq_cmdseq_map_name(cmd, "keyboard shortcut"));
 }
 
 /* 1999-03-17 -	Load in all key mappings. */
-static void keys_load(MainInfo *min, XmlNode *node)
+static void keys_load(MainInfo *min, const XmlNode *node)
 {
 	xml_node_visit_children(node, key_load, min);
 }
 
 /* 1999-06-20 -	Load and install a single mouse command mapping. */
-static void mousebutton_load(XmlNode *node, gpointer user)
+static void mousebutton_load(const XmlNode *node, gpointer user)
 {
-	gchar	*cmd;
-	guint	button, state;
+	const gchar	*cmd;
+	guint		button, state;
 
 	if(xml_get_uinteger(node, "button", &button) && xml_get_uinteger(node, "state", &state) && xml_get_text(node, "cmdseq", &cmd))
 		ctrl_mouse_add(((MainInfo *) user)->cfg.ctrlinfo, button, state, csq_cmdseq_map_name(cmd, "dirpane mouse button"));
 }
 
 /* 1999-06-20 -	Load in the mouse command bindings. */
-static void mousebuttons_load(MainInfo *min, XmlNode *node)
+static void mousebuttons_load(MainInfo *min, const XmlNode *node)
 {
 	xml_node_visit_children(node, mousebutton_load, min);
 }
 
 /* 1999-03-17 -	Load in the control config information. Replaces current. */
-static void cct_load(MainInfo *min, XmlNode *node)
+static void cct_load(MainInfo *min, const XmlNode *node)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
-	if((node = (xml_tree_search(node, "Controls"))) != NULL)
+	if((node = xml_tree_search(node, "Controls")) != NULL)
 	{
 		gboolean	tmp;
 
