@@ -86,6 +86,13 @@ typedef struct {
 	DpCol		index;		/* This is just used when editing, to record which color is being edited. */
 } PColors;
 
+typedef struct {
+	GtkWidget	*vbox;
+	GtkWidget	*mode[4];
+	GtkWidget	*value;		/* Pointer to current value-holding widget. */
+	DPPaning	edit;
+} PPaning;
+
 struct P_DirPane {		/* Information this module likes to have around. */
 	GtkWidget	*vbox;		/* Root vbox, holds rest of GUI. Returned. */
 	GtkWidget	*high_hbox;	/* Upper hbox, holds mostly buttons. */
@@ -94,6 +101,7 @@ struct P_DirPane {		/* Information this module likes to have around. */
 
 	PDef		pane[2];
 	PColors		colors;
+	PPaning		paning;
 
 	MainInfo	*min;
 };
@@ -146,7 +154,8 @@ static P_DirPane	the_page;	/* There can be only one. */
 static gchar	*config_name[] = { "DirPaneLeft", "DirPaneRight" },
 		*mode_name[] = { "dirs_first", "dirs_last", "dirs_mixed" },
 		*sbarpos_name[] = { "system", "left", "right" },
-		*color_name[] = { "pane_selected", "focus_unselected", "focus_selected" };
+		*color_name[] = { "pane_selected", "focus_unselected", "focus_selected" },
+		*paning_name[] = { "free", "ratio", "absleft", "absright" };
 
 /* ----------------------------------------------------------------------------------------- */
 
@@ -201,6 +210,28 @@ static void set_color_widgets(PColors *col)
 		od_emil_button_set_colors(OD_EMIL_BUTTON(col->widget[i]), OD_EMIL_BUTTON_PRIMARY, NULL, &col->edit.color[i]);
 }
 
+static void set_paning_widgets(PPaning *p)
+{
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(p->mode[p->edit.mode]), TRUE);
+	switch(p->edit.mode)
+	{
+		case DPSPLIT_FREE:
+			break;
+		case DPSPLIT_RATIO:
+			gtk_adjustment_set_value(gtk_range_get_adjustment(GTK_RANGE(p->value)), p->edit.value);
+			break;
+		case DPSPLIT_ABS_LEFT:
+		case DPSPLIT_ABS_RIGHT:
+			{
+				gchar	buf[32];
+
+				g_snprintf(buf, sizeof buf, "%d", (gint) p->edit.value);
+				gtk_entry_set_text(GTK_ENTRY(p->value), buf);
+			}
+			break;
+	}
+}
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-15 -	Add a column showing the indicated content to the selected list of <def>. */
@@ -655,16 +686,6 @@ static void evt_sclist_remove_clicked(GtkWidget *wid, gpointer user)
 	}
 }
 
-/* 1999-05-15 -	Swap columns <c1> and <c2>. Typically used to move up or down. */
-static void column_swap(PDef *def, gint c1, gint c2)
-{
-	DpCFmt	tmp;
-
-	tmp = def->edit.format[c1];
-	def->edit.format[c1] = def->edit.format[c2];
-	def->edit.format[c2] = tmp;
-}
-
 /* 1999-05-15 -	The "up" arrow has been hit. Move the currently selected column. */
 static void evt_sclist_up_clicked(GtkWidget *wid, gpointer user)
 {
@@ -674,7 +695,6 @@ static void evt_sclist_up_clicked(GtkWidget *wid, gpointer user)
 	row = def->sclist_row;
 	if(row > 0)
 	{
-		column_swap(def, row, row - 1);
 		gtk_clist_row_move(GTK_CLIST(def->sclist), row, row - 1);
 		gtk_clist_select_row(GTK_CLIST(def->sclist), row - 1, -1);
 		gtk_clist_moveto(GTK_CLIST(def->sclist), row - 1, -1, 0.0, 0.0);
@@ -690,7 +710,6 @@ static void evt_sclist_down_clicked(GtkWidget *wid, gpointer user)
 	row = def->sclist_row;
 	if((row >= 0) && (row < def->edit.num_columns))
 	{
-		column_swap(def, row, row + 1);
 		gtk_clist_row_move(GTK_CLIST(def->sclist), row, row + 1);
 		gtk_clist_select_row(GTK_CLIST(def->sclist), row + 1, -1);
 		gtk_clist_moveto(GTK_CLIST(def->sclist), row + 1, -1, 1.0, 0.0);
@@ -1122,6 +1141,68 @@ static void init_color_page(P_DirPane *page)
 	gtk_widget_show(table);
 }
 
+static void evt_pane_mode_toggled(GtkWidget *wid, gpointer user)
+{
+	P_DirPane	*page = user;
+	GtkWidget	*row;
+
+	if((row = gtk_object_get_data(GTK_OBJECT(wid), "row")) != NULL)
+		gtk_widget_set_sensitive(row, GTK_TOGGLE_BUTTON(wid)->active);	/* Sometimes, GTK+ is just plain nice. */
+	if(GTK_TOGGLE_BUTTON(wid)->active)
+	{
+		page->paning.edit.mode = (DpSplit) GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(wid), "index"));
+		page->paning.value = gtk_object_get_data(GTK_OBJECT(wid), "value");
+	}
+}
+
+static void init_paning_page(P_DirPane *page)
+{
+	PPaning		*p = &page->paning;
+	GtkWidget	*table, *rb, *lrb, *row, *value = NULL;
+	const gchar	*modename[] = { N_("Don't Track"), N_("Ratio"), N_("Size, Left Pane"), N_("Size, Right Pane") };
+	guint		i;
+
+	p->vbox = gtk_vbox_new(FALSE, 0);
+	table = gtk_table_new(sizeof modename / sizeof modename[0], 2, FALSE);
+	for(i = 0, lrb = NULL; i < sizeof modename / sizeof modename[0]; i++, lrb = rb)
+	{
+		p->mode[i] = rb = gtk_radio_button_new_with_label_from_widget(lrb ? GTK_RADIO_BUTTON(lrb) : NULL, modename[i]);
+		row = NULL;
+		if(i == 1)
+		{
+			GtkObject	*adj;
+
+			adj = gtk_adjustment_new(0.5, 0.0, 1.0, 0.0125, 0.125, 0);
+			row = value = gtk_hscale_new(GTK_ADJUSTMENT(adj));
+			gtk_scale_set_digits(GTK_SCALE(value), 4);
+			gtk_scale_set_value_pos(GTK_SCALE(value), GTK_POS_RIGHT);
+		}
+		else if(i == 2 || i == 3)
+		{
+			GtkWidget	*label;
+
+			row = gtk_hbox_new(FALSE, 0);
+			value = gtk_entry_new();
+			gtk_entry_set_text(GTK_ENTRY(value), "256");	/* Better than being empty. */
+			gtk_box_pack_start(GTK_BOX(row), value, TRUE, TRUE, 0);
+			label = gtk_label_new(_("pixels"));
+			gtk_box_pack_start(GTK_BOX(row), label, FALSE, FALSE, 5);
+		}
+		gtk_object_set_data(GTK_OBJECT(rb), "index", GINT_TO_POINTER(i));
+		gtk_signal_connect(GTK_OBJECT(rb), "toggled", GTK_SIGNAL_FUNC(evt_pane_mode_toggled), page);
+		gtk_table_attach(GTK_TABLE(table), rb, 0, 1, i, i+1, GTK_FILL,0,0,0);
+		if(row != NULL)
+		{
+			gtk_object_set_data(GTK_OBJECT(rb), "row", row);
+			gtk_object_set_data(GTK_OBJECT(rb), "value", value);
+			gtk_widget_set_sensitive(row, FALSE);
+			gtk_table_attach(GTK_TABLE(table), row, 1, 2, i, i+1, GTK_EXPAND|GTK_FILL,0,0,0);
+		}
+	}
+	gtk_box_pack_start(GTK_BOX(p->vbox), table, FALSE, FALSE, 0);
+	gtk_widget_show_all(table);
+}
+
 /* 1998-06-22 -	Called by the main configuration code as it opens up. Asks this module
 **		to initialize itself, and return a pointer to the root of its widgetry.
 **		This module should also set the <name> pointer to its name ("DirPane").
@@ -1152,6 +1233,10 @@ static GtkWidget * cdp_init(MainInfo *min, gchar **name)
 	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->colors.vbox, gtk_label_new(_("Colors")));
 	gtk_widget_show(page->colors.vbox);
 
+	init_paning_page(page);
+	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->paning.vbox, gtk_label_new(_("Pane Split")));
+	gtk_widget_show(page->paning.vbox);
+
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->notebook, TRUE, TRUE, 5);
 	gtk_widget_show(page->notebook);
 
@@ -1171,10 +1256,12 @@ static void cdp_update(MainInfo *min)
 	for(i = 0; i < sizeof the_page.pane / sizeof the_page.pane[0]; i++)
 		the_page.pane[i].edit = min->cfg.dp_format[i];
 	the_page.colors.edit = min->cfg.dp_colors;
+	the_page.paning.edit = min->cfg.dp_paning;
 
 	set_pane_widgets(&the_page.pane[0]);
 	set_pane_widgets(&the_page.pane[1]);
 	set_color_widgets(&the_page.colors);
+	set_paning_widgets(&the_page.paning);
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -1193,11 +1280,28 @@ static void cdp_accept(MainInfo *min)
 			min->cfg.dp_format[i] = the_page.pane[i].edit;
 			cfg_set_flags(CFLG_REBUILD_MIDDLE | CFLG_RESCAN_LEFT | CFLG_RESCAN_RIGHT);
 		}
-		if(memcmp(&the_page.colors.edit, &min->cfg.dp_colors, sizeof the_page.colors.edit) != 0)
-		{
-			min->cfg.dp_colors = the_page.colors.edit;
-			cfg_set_flags(CFLG_REBUILD_MIDDLE | CFLG_RESCAN_LEFT | CFLG_RESCAN_RIGHT);
-		}
+	}
+	if(memcmp(&the_page.colors.edit, &min->cfg.dp_colors, sizeof the_page.colors.edit) != 0)
+	{
+		min->cfg.dp_colors = the_page.colors.edit;
+		cfg_set_flags(CFLG_REBUILD_MIDDLE | CFLG_RESCAN_LEFT | CFLG_RESCAN_RIGHT);
+	}
+	switch(the_page.paning.edit.mode)
+	{
+		case DPSPLIT_FREE:
+			break;
+		case DPSPLIT_RATIO:
+			the_page.paning.edit.value = gtk_range_get_adjustment(GTK_RANGE(the_page.paning.value))->value;
+			break;
+		case DPSPLIT_ABS_LEFT:
+		case DPSPLIT_ABS_RIGHT:
+			the_page.paning.edit.value = strtol(gtk_entry_get_text(GTK_ENTRY(the_page.paning.value)), NULL, 10);
+			break;
+	}
+	if(memcmp(&the_page.paning.edit, &min->cfg.dp_paning, sizeof the_page.paning.edit) != 0)
+	{
+		min->cfg.dp_paning = the_page.paning.edit;
+		cfg_set_flags(CFLG_REBUILD_MIDDLE);
 	}
 }
 
@@ -1301,6 +1405,14 @@ static void save_colors(FILE *out, DPColors *cols)
 	xml_put_node_close(out, "DirPaneColors");
 }
 
+static void save_paning(FILE *out, DPPaning *p)
+{
+	xml_put_node_open(out, "DirPanePaning");
+	xml_put_text(out, "mode", paning_name[p->mode]);
+	xml_put_real(out, "value", p->value);
+	xml_put_node_close(out, "DirPanePaning");
+}
+
 /* 1998-07-25 -	Save out the dirpane configuration information, in XML format. Might tend
 **		to be kind of huge.
 */
@@ -1313,6 +1425,7 @@ static gint cdp_save(MainInfo *min, FILE *out)
 	for(i = 0; i < num; i++)
 		save_pane(out, &min->cfg.dp_format[i], config_name[i]);
 	save_colors(out, &min->cfg.dp_colors);
+	save_paning(out, &min->cfg.dp_paning);
 	xml_put_node_close(out, NODE);
 
 	return TRUE;
@@ -1324,7 +1437,7 @@ static gint cdp_save(MainInfo *min, FILE *out)
 **		really rely on the fact (?) that fields of a union all have the same
 **		offset from it (namely 0).
 */
-static void load_extra(XmlNode *node, DPContent content, DpCExtra *extra)
+static void load_extra(const XmlNode *node, DPContent content, DpCExtra *extra)
 {
 	gint	tmp;
 
@@ -1381,10 +1494,10 @@ static void load_extra(XmlNode *node, DPContent content, DpCExtra *extra)
 }
 
 /* 1998-07-26 -	Load sorting configuration. */
-static void load_sort(XmlNode *node, DPSort *sort)
+static void load_sort(const XmlNode *node, DPSort *sort)
 {
-	gchar	*content, *mode;
-	gint	tmp;
+	const gchar	*content, *mode;
+	gint		tmp;
 
 	if(xml_get_text(node, "content", &content))
 		sort->content = dpf_get_content_from_name(content);
@@ -1403,7 +1516,7 @@ static void load_sort(XmlNode *node, DPSort *sort)
 			}
 		}
 		if(!found)
-			fprintf(stderr, _("**DPCFG: Unknown sort mode %s\n"), mode);
+			g_warning(_("**DPCFG: Unknown sort mode %s\n"), mode);
 	}
 	if(xml_get_boolean(node, "invert", &tmp))
 		sort->invert = tmp;
@@ -1417,12 +1530,12 @@ static void load_sort(XmlNode *node, DPSort *sort)
 **		xml_node_visit_children() function, we must make sure that the given node
 **		really is for a column.
 */
-static void load_column(XmlNode *node, gpointer user)
+static void load_column(const XmlNode *node, gpointer user)
 {
 	DPFormat	*fmt = (DPFormat *) user;
 	DpCFmt		*colfmt;
-	XmlNode		*data;
-	gchar		*cnt;
+	const XmlNode	*data;
+	const gchar	*cnt;
 	gint		index;
 	DPContent	cid;
 
@@ -1447,11 +1560,11 @@ static void load_column(XmlNode *node, gpointer user)
 		fprintf(stderr, _("**DPCFG: Config node missing 'index' leaf\n"));
 }
 
-static void load_pane(XmlNode *node, DPFormat *fmt)
+static void load_pane(const XmlNode *node, DPFormat *fmt)
 {
-	XmlNode *data;
-	gchar	*sbarpos;
-	gint	tmp;
+	const XmlNode	*data;
+	const gchar	*sbarpos;
+	gint		tmp;
 
 	if(xml_get_integer(node, "columns", (gint *) &fmt->num_columns))
 	{
@@ -1490,7 +1603,7 @@ static void load_pane(XmlNode *node, DPFormat *fmt)
 	}
 }
 
-static void load_colors(XmlNode *node, DPColors *colors)
+static void load_colors(const XmlNode *node, DPColors *colors)
 {
 	guint	i;
 
@@ -1498,11 +1611,33 @@ static void load_colors(XmlNode *node, DPColors *colors)
 		xml_get_color(node, color_name[i], &colors->color[i]);
 }
 
-/* 1998-07-26 -	Load (e.g. parse) the DirPane data found in the XML tree <node>. */
-static void cdp_load(MainInfo *min, XmlNode *node)
+static void load_paning(const XmlNode *node, DPPaning *paning)
 {
-	XmlNode	*pane, *cols;
-	gint	num, i;
+	const gchar	*str;
+	gfloat		tmp;
+
+	if(xml_get_text(node, "mode", &str))
+	{
+		guint	i;
+
+		for(i = 0; i < sizeof paning_name / sizeof paning_name[0]; i++)
+		{
+			if(strcmp(paning_name[i], str) == 0)
+			{
+				paning->mode = i;
+				break;
+			}
+		}
+	}
+	if(xml_get_real(node, "value", &tmp))
+		paning->value = tmp;
+}
+
+/* 1998-07-26 -	Load (e.g. parse) the DirPane data found in the XML tree <node>. */
+static void cdp_load(MainInfo *min, const XmlNode *node)
+{
+	const XmlNode	*pane, *sub;
+	gint		num, i;
 
 	if(xml_get_integer(node, "count", &num))
 	{
@@ -1514,8 +1649,10 @@ static void cdp_load(MainInfo *min, XmlNode *node)
 				fprintf(stderr, _("**DPCFG: Couldn't find '%s' in config file!\n"), config_name[i]);
 		}
 	}
-	if((cols = xml_tree_search(node, "DirPaneColors")) != NULL)
-		load_colors(cols, &min->cfg.dp_colors);
+	if((sub = xml_tree_search(node, "DirPaneColors")) != NULL)
+		load_colors(sub, &min->cfg.dp_colors);
+	if((sub = xml_tree_search(node, "DirPanePaning")) != NULL)
+		load_paning(sub, &min->cfg.dp_paning);
 }
 
 /* ----------------------------------------------------------------------------------------- */
