@@ -148,25 +148,21 @@ static GtkWidget * cpt_init(MainInfo *min, gchar **name)
 		{
 			label = gtk_label_new(_(labtxt[i]));
 			gtk_table_attach(GTK_TABLE(page->ptable), label, 0, 1, i, i+1, 0,0,0,0);
-			gtk_widget_show(label);
 			page->path[i].path = gtk_entry_new();
 			gtk_signal_connect(GTK_OBJECT(page->path[i].path), "changed", GTK_SIGNAL_FUNC(evt_path_changed), (gpointer) page);
 			gtk_table_attach_defaults(GTK_TABLE(page->ptable), page->path[i].path, 1, 2, i, i+1);
-#if defined(__OpenBSD__) || defined(__FreeBSD__)
+#if defined __OpenBSD__ || defined __FreeBSD__ || defined __NetBSD__
 			/* Mountlist and mounted fs files are non-configurable on BSD systems. */
 			if(i == 2 || i == 3)
 				gtk_widget_set_sensitive(page->path[i].path, FALSE);
 #endif
-			gtk_widget_show(page->path[i].path);
 		}
 	}
 	else
-		fprintf(stderr, "**CFGPATHS: Missing labels!\n");
+		g_warning("**CFGPATHS: Missing labels!");
 
 	gtk_container_add(GTK_CONTAINER(page->pframe), page->ptable);
-	gtk_widget_show(page->ptable);
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->pframe, FALSE, FALSE, 5);
-	gtk_widget_show(page->pframe);
 
 	page->hide.frame  = gtk_frame_new(_("Hide Entries"));
 	page->hide.hgroup = gui_radio_group_new(3, hlab, page->hide.hmode);
@@ -176,35 +172,26 @@ static GtkWidget * cpt_init(MainInfo *min, gchar **name)
 		gtk_object_set_data(GTK_OBJECT(page->hide.hmode[i]), "mode", GINT_TO_POINTER(i));
 		gtk_signal_connect(GTK_OBJECT(page->hide.hmode[i]), "clicked", GTK_SIGNAL_FUNC(evt_hmode_clicked), (gpointer) page);
 		if(i < 2)
-		{
 			gtk_box_pack_start(GTK_BOX(vbox), page->hide.hmode[i], FALSE, FALSE, 0);
-			gtk_widget_show(page->hide.hmode[i]);
-		}
 		else
 		{
 			GtkWidget	*hbox;
 
 			hbox = gtk_hbox_new(FALSE, 0);
 			gtk_box_pack_start(GTK_BOX(hbox), page->hide.hmode[i], FALSE, FALSE, 0);
-			gtk_widget_show(page->hide.hmode[i]);
 			page->hide.hre = gtk_entry_new_with_max_length(sizeof min->cfg.path.hideinfo.hide_re_src - 1);
 			gtk_signal_connect(GTK_OBJECT(page->hide.hre), "changed", GTK_SIGNAL_FUNC(evt_hre_changed), (gpointer) page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->hide.hre, TRUE, TRUE, 0);
-			gtk_widget_show(page->hide.hre);
 			page->hide.hicase = gtk_check_button_new_with_label(_("No Case?"));
 			gtk_signal_connect(GTK_OBJECT(page->hide.hicase), "clicked", GTK_SIGNAL_FUNC(evt_hicase_clicked), (gpointer) page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->hide.hicase, FALSE, FALSE, 0);
-			gtk_widget_show(page->hide.hicase);
 			gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-			gtk_widget_show(hbox);
 		}
 	}
 	gtk_container_add(GTK_CONTAINER(page->hide.frame), vbox);
-	gtk_widget_show(vbox);
-	gtk_box_pack_start(GTK_BOX(page->vbox), page->hide.frame, FALSE, FALSE, 0);
-	gtk_widget_show(page->hide.frame);
+	gtk_box_pack_start(GTK_BOX(page->vbox), page->hide.frame, FALSE, FALSE, 5);
 
-	gtk_widget_show(page->vbox);
+	gtk_widget_show_all(page->vbox);
 
 	return page->vbox;
 }
@@ -291,25 +278,26 @@ static gint cpt_save(MainInfo *min, FILE *out)
 	return TRUE;
 }
 
-static void load_path(XmlNode *data, gpointer user)
+static void load_path(const XmlNode *data, gpointer user)
 {
 	CfgInfo	*cfg = (CfgInfo *) user;
-	char	*path;
 	gint	index;
 
 	if(xml_get_integer(data, "index", &index))
 	{
-		if(index >= 0 && index < PTID_NUM_PATHS)
+		if((index >= 0) && (index < PTID_NUM_PATHS))
 		{
+			const gchar	*path;
+
 			if(xml_get_text(data, "path", &path))
 				g_string_assign(cfg->path.path[index], path);
 		}
 		else
-			fprintf(stderr, "**CFGPATHS: Path index %d is illegal\n", index);
+			g_warning("**CFGPATHS: Path index %d is illegal", index);
 	}
 }
 
-static void load_hideinfo(MainInfo *min, XmlNode *node)
+static void load_hideinfo(MainInfo *min, const XmlNode *node)
 {
 	gint	tmp;
 
@@ -320,9 +308,9 @@ static void load_hideinfo(MainInfo *min, XmlNode *node)
 }
 
 /* 1998-08-24 -	Load paths from config tree. Ugly. */
-static void cpt_load(MainInfo *min, XmlNode *node)
+static void cpt_load(MainInfo *min, const XmlNode *node)
 {
-	XmlNode		*data;
+	const XmlNode		*data;
 
 	if((data = xml_tree_search(node, "PathList")) != NULL)
 		xml_node_visit_children(data, load_path, (gpointer) &min->cfg);
