@@ -530,7 +530,7 @@ static gint csc_save(MainInfo *min, FILE *out)
 
 /* ----------------------------------------------------------------------------------------- */
 
-static void load_shortcut(XmlNode *node, gpointer user)
+static void load_shortcut(const XmlNode *node, gpointer user)
 {
 	ShortcutBank	*bank = (ShortcutBank *) user;
 	Shortcut	*shc;
@@ -547,10 +547,10 @@ static void load_shortcut(XmlNode *node, gpointer user)
 	}
 }
 
-static void load_shortcutbank(XmlNode *node, gpointer user)
+static void load_shortcutbank(const XmlNode *node, gpointer user)
 {
 	MainInfo	*min = (MainInfo *) user;
-	XmlNode		*data;
+	const XmlNode	*data;
 	gint		tmp;
 
 	if(xml_get_boolean(node, "visible", &tmp))
@@ -566,7 +566,7 @@ static void load_shortcutbank(XmlNode *node, gpointer user)
 }
 
 /* 1998-07-30 -	Load in the shortcut data from given tree. */
-static void csc_load(MainInfo *min, XmlNode *node)
+static void csc_load(MainInfo *min, const XmlNode *node)
 {
 	xml_node_visit_children(node, load_shortcutbank, (gpointer) min);
 }
