@@ -784,14 +784,6 @@ static void cst_accept(MainInfo *min)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-08-24 -	Load style configuration info from given XML tree. */
-static void cst_load(MainInfo *min, XmlNode *node)
-{
-	/* Free the built-in first. */
-	stl_styleinfo_destroy(min->cfg.style);
-	min->cfg.style = stl_styleinfo_load(node);
-}
-
 /* 1999-05-27 -	Save the current style configuration. Thanks to the styles module, this
 **		is really not complicated. :)
 */
@@ -802,6 +794,14 @@ static int cst_save(MainInfo *min, FILE *out)
 	return TRUE;
 }
 
+/* 1998-08-24 -	Load style configuration info from given XML tree. */
+static void cst_load(MainInfo *min, const XmlNode *node)
+{
+	/* Free the built-in first. */
+	stl_styleinfo_destroy(min->cfg.style);
+	min->cfg.style = stl_styleinfo_load(node);
+}
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-27 -	When the config window closes, free the editing copies since they're bulky. */
