@@ -820,12 +820,12 @@ static gint ctp_save(MainInfo *min, FILE *out)
 ** 1999-03-07 -	Fixed huge bug, where a pointer to mode_t was cast to int *.
 **		Not good, since mode_t is just 16 bit...
 */
-static void load_type(XmlNode *node, gpointer user)
+static void load_type(const XmlNode *node, gpointer user)
 {
-	CfgInfo	*cfg = (CfgInfo *) user;
-	gchar	*name = NULL, *suffix = NULL, *name_re = NULL, *file_re = NULL, *style = NULL;
-	gint	perm = 0, tmp, mode;
-	FType	*tpe;
+	CfgInfo		*cfg = (CfgInfo *) user;
+	const gchar	*name = NULL, *suffix = NULL, *name_re = NULL, *file_re = NULL, *style = NULL;
+	gint		perm = 0, tmp, mode;
+	FType		*tpe;
 
 	xml_get_text(node, "name", &name);
 	xml_get_integer(node, "mode", &mode);
@@ -851,7 +851,7 @@ static void load_type(XmlNode *node, gpointer user)
 }
 
 /* 1998-08-14 -	Load in the filetypes hanging off of <node>. */
-static void ctp_load(MainInfo *min, XmlNode *node)
+static void ctp_load(MainInfo *min, const XmlNode *node)
 {
 	GList	*old, *next;
 
