@@ -66,15 +66,15 @@ int cmd_about(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 	{
 		w = gtk_pixmap_new(pmap, mask);
 		gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 5);
-		w = gtk_label_new(buf);
-		gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
-		w = gtk_label_new("(c) 1998-2000 by Emil Brink, Obsession Development.\n");
-		gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
-		w = gtk_label_new(_("This is free software, and there is ABSOLUTELY NO\n"
-				"WARRANTY. Read the file COPYING for more details.\n\n"
-				"Using built-in English strings."));
-		gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
 	}
+	w = gtk_label_new(buf);
+	gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
+	w = gtk_label_new("(c) 1998-2002 by Emil Brink, Obsession Development.\n");
+	gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
+	w = gtk_label_new(_("This is free software, and there is ABSOLUTELY NO\n"
+			"WARRANTY. Read the file COPYING for more details.\n\n"
+			"Using built-in English strings."));
+	gtk_box_pack_start(GTK_BOX(body->page[0]), w, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), body->page[0], TRUE, TRUE, 0);
 	gtk_widget_show_all(body->page[0]);
 	body->page[1] = gtk_label_new(	_("The author of gentoo can be reached via Internet\n"
@@ -86,13 +86,13 @@ int cmd_about(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 
 					"The latest release of gentoo can always be down-\n"
 					"loaded from the official gentoo project homepage at\n"
-					"<http://www.obsession.se/gentoo>. New releases are\n"
+					"<http://www.obsession.se/gentoo/>. New releases are\n"
 					"typically announced on the Freshmeat service at\n"
-					"<http://freshmeat.net>."));
+					"<http://freshmeat.net/>."));
 	gtk_box_pack_start(GTK_BOX(hbox), body->page[1], TRUE, TRUE, 0);
 
 	body->handle = gtk_timeout_add(10000, timeout_trigger, body);
-	dlg_dialog_async_new(hbox, _("About gentoo"), _("OK"), timeout_remove, body);
+	dlg_dialog_async_new(hbox, _("About gentoo"), _("OK (Wait for More)"), timeout_remove, body);
 
 	return 1;
 }
