@@ -11,6 +11,7 @@
 #include "gentoo.h"
 #include "fileutil.h"
 #include "dirpane.h"
+#include "errors.h"
 #include "overwrite.h"
 #include "progress.h"
 #include "strutil.h"
@@ -63,7 +64,7 @@ static void cpa_copy_body(MainInfo *min, DirPane *src, DirRow *row, GtkWindow *w
 		if(cpa->action == CPA_COPYAS)
 			ovw_overwrite_begin(min, _("\"%s\" Already Exists - Proceed With Copy?"), 0U);
 		else
-			ovw_overwrite_begin(min, _("\"%s\" Already Exists - Ccontinue With Clone?"), 0U);
+			ovw_overwrite_begin(min, _("\"%s\" Already Exists - Continue With Clone?"), 0U);
 		pgs_progress_begin(min, cpa->action == CPA_COPYAS ? _("Copying As...") : _("Cloning..."), -1);
 		cpa->ovw_open = TRUE;
 	}
@@ -93,12 +94,24 @@ static void cpa_link_body(MainInfo *min, DirPane *src, DirRow *row, GtkWindow *w
 
 	if(cpa->ovw_open == FALSE)
 	{
-		ovw_overwrite_begin(min, _("\"%s\" Already Exists - Proceed With Symlink?"), 0U);
+		ovw_overwrite_begin(min, _("\"%s\" Already Exists - Proceed With Symlink?"), OVWF_NO_RECURSE_TEST);
 		pgs_progress_begin(min, "Linking...", -1);
 		cpa->ovw_open = TRUE;
 	}
 }
 
+static const gchar * op_name(CpaAction action)
+{
+	switch(action)
+	{
+		case CPA_COPYAS:	return "CopyAs";
+		case CPA_CLONE:		return "Clone";
+		case CPA_SYMLINKAS:	return "SymLinkAs";
+		case CPA_SYMLINKCLONE:	return "SymLinkClone";
+	}
+	return NULL;
+}
+
 /* 1998-09-12 -	Perform action for copy as/clone command. */
 static int cpa_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gpointer user)
 {
@@ -134,7 +147,11 @@ static int cpa_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gp
 		if(ores == OVW_SKIP)
 			return 1;
 		else if(ores == OVW_CANCEL)
+		{
+			if(errno)
+				err_set(min, errno, op_name(cpa->action), dp_full_name(src, DP_ROW_INDEX(src, row)));
 			return 0;
+		}
 
 		if((cpa->action == CPA_COPYAS) || (cpa->action == CPA_CLONE))	/* Copy? */
 		{
