@@ -91,7 +91,7 @@ int cmd_dpfocus(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 			break;
 		case CMD_PREV:
 			if(src->focus_row == -1)
-				dp_focus(src, src->dir.num_lines - 1);
+				dp_focus(src, src->dir.num_rows - 1);
 			else
 			{
 				gint	dest = src->focus_row - 1;
@@ -99,7 +99,7 @@ int cmd_dpfocus(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 				if(dest < 0)
 				{
 					if(dpfocus_options.edge_wrap)
-						dest = src->dir.num_lines - 1;
+						dest = src->dir.num_rows - 1;
 					else
 						dest = 0;
 				}
@@ -114,12 +114,12 @@ int cmd_dpfocus(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 			{
 				gint	dest = src->focus_row + 1;
 
-				if(dest >= src->dir.num_lines)
+				if(dest >= src->dir.num_rows)
 				{
 					if(dpfocus_options.edge_wrap)
 						dest = 0;
 					else
-						dest = src->dir.num_lines - 1;
+						dest = src->dir.num_rows - 1;
 				}
 				if(dest != src->focus_row)
 					dp_focus(src, dest);
@@ -127,7 +127,7 @@ int cmd_dpfocus(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 			break;
 		case CMD_PAGEPREV:
 			if(src->focus_row == -1)
-				dp_focus(src, src->dir.num_lines - 1);
+				dp_focus(src, src->dir.num_rows - 1);
 			else
 				move_page(src, -1);
 			break;
@@ -141,7 +141,7 @@ int cmd_dpfocus(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 			dp_focus(src, 0);
 			break;
 		case CMD_LAST:
-			dp_focus(src, src->dir.num_lines - 1);
+			dp_focus(src, src->dir.num_rows - 1);
 			break;
 		case CMD_ACTIVATE:
 			dp_dbclk_row(src, src->focus_row);
