@@ -7,6 +7,7 @@
 ** 1999-04-05 -	Added use of the new command configuration system, to allow user to have
 **		some control over how this command operates. Nice.
 ** 2000-07-02 -	Internationalized. Lost some hard-coded plural suffix stuff (was English-only). :(
+** 2002-02-08 -	Now uses the dialog module. Why it wasn't, nobody knows.
 */
 
 #include "gentoo.h"
@@ -14,6 +15,8 @@
 #include <time.h>
 
 #include "errors.h"
+#include "file.h"
+#include "dialog.h"
 #include "dirpane.h"
 #include "iconutil.h"
 #include "sizeutil.h"
@@ -31,6 +34,7 @@
 
 typedef struct {
 	gboolean modified;
+	gboolean use_file;			/* Show 'file' output? */
 	gboolean recurse_dirs;			/* Recurse directories? */
 	gchar	 df_access[DP_DATEFMT_SIZE];	/* Formatter for dates of last access, */
 	gchar	 df_modify[DP_DATEFMT_SIZE];	/*  modification, */
@@ -50,7 +54,6 @@ static void build_date(const gchar *label, gint y, time_t *date, const gchar *fm
 
 	lab = gtk_label_new(label);
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 
 	if((tm = localtime(date)) != NULL)
 	{
@@ -58,7 +61,6 @@ static void build_date(const gchar *label, gint y, time_t *date, const gchar *fm
 		{
 			lab = gtk_label_new(buf);
 			gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-			gtk_widget_show(lab);
 		}
 	}
 }
@@ -72,7 +74,7 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 	GdkPixmap	*ipix;
 	GdkBitmap	*imsk;
 
-	tab = gtk_table_new(15, 2, FALSE);
+	tab = gtk_table_new(17, 2, FALSE);
 
 	y = 0;
 	if(DP_ROW_TYPE(row)->style != NULL)
@@ -82,12 +84,10 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 			ipix = ico_icon_get(min, iname, &imsk);
 			ico = gtk_pixmap_new(ipix, imsk);
 			gtk_table_attach(GTK_TABLE(tab), ico, 0, 1, y, y + 1, 0,0,5,5);
-			gtk_widget_show(ico);
 		}
 	}
 	lab = gtk_label_new(DP_ROW_NAME(row));
 	gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, GTK_EXPAND,0,5,5);
-	gtk_widget_show(lab);
 	y++;
 
 	/* For symbolic links, display name of the target, at least. */
@@ -97,43 +97,34 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 
 		lab = gtk_label_new(_("Link To"));
 		gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-		gtk_widget_show(lab);		
 		scwin = gtk_scrolled_window_new(NULL, NULL);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 		text = gtk_text_new(NULL, NULL);
 		gtk_text_set_editable(GTK_TEXT(text), FALSE);
 		gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, DP_ROW_LINKNAME(row), strlen(DP_ROW_LINKNAME(row)));
 		gtk_container_add(GTK_CONTAINER(scwin), text);
-		gtk_widget_show(text);
 		gtk_table_attach(GTK_TABLE(tab), scwin, 1, 2, y, y + 1,  GTK_EXPAND|GTK_FILL,GTK_EXPAND|GTK_FILL,5,0);
-		gtk_widget_show(scwin);
 		y++;
 	}
 
 	sep = gtk_hseparator_new();
 	gtk_table_attach(GTK_TABLE(tab), sep, 0, 2, y, y + 1, GTK_EXPAND | GTK_FILL,0,0,5);
-	gtk_widget_show(sep);
 	y++;
 
 	lab = gtk_label_new(_("Type"));
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	lab = gtk_label_new(DP_ROW_TYPE(row)->name);
 	gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	y++;
 
 	lab = gtk_label_new(_("Location"));
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	lab = gtk_label_new(dp->dir.path);
 	gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	y++;
 
 	lab = gtk_label_new(_("Size"));
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	sze_put_size(DP_ROW_LSTAT(row).st_size, sbuf, sizeof sbuf, SZE_AUTO);
 	if(DP_ROW_LSTAT(row).st_size < 1024)
 		stu_strncpy(buf, sbuf, sizeof buf);
@@ -141,7 +132,6 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 		g_snprintf(buf, sizeof buf, _("%s (%u bytes)"), sbuf, (gsize) DP_ROW_LSTAT(row).st_size);
 	szlab = gtk_label_new(buf);
 	gtk_table_attach(GTK_TABLE(tab), szlab, 1, 2, y, y + 1, 0,0,5,0);
-	gtk_widget_show(szlab);
 	y++;
 
 	/* Building info for a directory, and recursing enabled? */
@@ -162,48 +152,57 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 			/* And tell a little something about the contents. */
 			lab = gtk_label_new(_("Contains"));
 			gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-			gtk_widget_show(lab);
 			g_snprintf(buf, sizeof buf, _("%d dirs, %d files, %d symlinks"),
 					fc.num_dirs, fc.num_files, fc.num_links);
 			lab = gtk_label_new(buf);
 			gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-			gtk_widget_show(lab);
 			y++;
 		}
 	}
 
+	/* Is the "Show 'file' Output?" option enabled? Requires "file -n -f -" to work. */
+#if defined HAS_GOOD_FILE
+	if(info_options.use_file)
+	{
+		gchar	buf[PATH_MAX];
+
+		sep = gtk_hseparator_new();
+		gtk_table_attach(GTK_TABLE(tab), sep, 0, 2, y, y + 1, GTK_EXPAND | GTK_FILL,0,0,5);
+		y++;
+		lab = gtk_label_new(_("'File' Info"));
+		gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
+		g_snprintf(buf, sizeof buf, "%s/%s", dp->dir.path, DP_ROW_NAME(row));
+		lab = gtk_label_new(fle_file(min, buf));
+		gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
+		y++;
+	}
+#endif
 	sep = gtk_hseparator_new();
 	gtk_table_attach(GTK_TABLE(tab), sep, 0, 2, y, y + 1, GTK_EXPAND | GTK_FILL,0,0,5);
-	gtk_widget_show(sep);
 	y++;
 
 	lab = gtk_label_new(_("Owner"));
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	if((ptr = (gchar *) usr_lookup_uname(DP_ROW_LSTAT(row).st_uid)) != NULL)
 		g_snprintf(buf, sizeof buf, "%s (%d)", ptr, (int) DP_ROW_LSTAT(row).st_uid);
 	else
 		g_snprintf(buf, sizeof buf, "%d", (int) DP_ROW_LSTAT(row).st_uid);
 	lab = gtk_label_new(buf);
 	gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	y++;
 
 	lab = gtk_label_new(_("Group"));
 	gtk_table_attach(GTK_TABLE(tab), lab, 0, 1, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	if((ptr = (gchar *) usr_lookup_gname(DP_ROW_LSTAT(row).st_gid)) != NULL)
 		g_snprintf(buf, sizeof buf, "%s (%d)", ptr, (int) DP_ROW_LSTAT(row).st_gid);
 	else
 		g_snprintf(buf, sizeof buf, "%d", (int) DP_ROW_LSTAT(row).st_gid);
 	lab = gtk_label_new(buf);
 	gtk_table_attach(GTK_TABLE(tab), lab, 1, 2, y, y + 1, 0,0,5,0);
-	gtk_widget_show(lab);
 	y++;
 
 	sep = gtk_hseparator_new();
 	gtk_table_attach(GTK_TABLE(tab), sep, 0, 2, y, y + 1, GTK_EXPAND | GTK_FILL,0,0,5);
-	gtk_widget_show(sep);
 	y++;
 
 	build_date(_("Accessed"), y++, &DP_ROW_LSTAT(row).st_atime, info_options.df_access, tab);
@@ -220,14 +219,6 @@ static GtkWidget * build_info(MainInfo *min, DirPane *dp, DirRow *row)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-12-19 -	As the user hits the "Close" button, we just destroy the GtkDialog widget. */
-static gint evt_close_clicked(GtkWidget *wid, gpointer data)
-{
-	gtk_widget_destroy(GTK_WIDGET(data));
-
-	return 1;
-}
-
 /* 1999-03-06 -	Create window showing all about <row>, which sits in <dp>. */
 static gint info(MainInfo *min, DirPane *dp, DirRow *row)
 {
@@ -235,19 +226,8 @@ static gint info(MainInfo *min, DirPane *dp, DirRow *row)
 
 	if((fr = build_info(min, dp, row)) != NULL)
 	{
-		GtkWidget	*dlg, *btn;
-
-		dlg = gtk_dialog_new();
-		gtk_window_set_title(GTK_WINDOW(dlg), DP_ROW_NAME(row));
-		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), fr, TRUE, TRUE, 0);
-		gtk_widget_show(fr);
-		btn = gtk_button_new_with_label(_("OK"));
-		GTK_WIDGET_SET_FLAGS(btn, GTK_CAN_DEFAULT);
-		gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_close_clicked), dlg);
-		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->action_area), btn, TRUE, TRUE, 0);
-		gtk_widget_show(btn);
-		gtk_widget_grab_default(btn);
-		gtk_widget_show(dlg);
+		gtk_widget_show_all(fr);
+		dlg_dialog_async_new(fr, DP_ROW_NAME(row), _("OK"), NULL, NULL);
 	}
 	return (fr != NULL) ? TRUE : FALSE;
 }
@@ -293,6 +273,7 @@ void cfg_information(MainInfo *min)
 	{
 		/* Initialize default option values. */
 		info_options.modified	  = FALSE;
+		info_options.use_file	  = FALSE;
 		info_options.recurse_dirs = TRUE;
 		stu_strncpy(info_options.df_access, "%Y-%m-%d %H:%M.%S", sizeof info_options.df_access);
 		stu_strncpy(info_options.df_modify, "%Y-%m-%d %H:%M.%S", sizeof info_options.df_modify);
@@ -300,6 +281,9 @@ void cfg_information(MainInfo *min)
 
 		info_cmc = cmc_config_new("Information", &info_options);
 		cmc_field_add_boolean(info_cmc, "modified", NULL, offsetof(OptInfo, modified));
+#if defined HAS_GOOD_FILE
+		cmc_field_add_boolean(info_cmc, "use_file", _("Show 'file' Output?"), offsetof(OptInfo, use_file));
+#endif
 		cmc_field_add_boolean(info_cmc, "recurse_dirs", _("Recurse Directories?"), offsetof(OptInfo, recurse_dirs));
 		cmc_field_add_string(info_cmc, "df_access", _("Access Date Format"), offsetof(OptInfo, df_access), sizeof info_options.df_access);
 		cmc_field_add_string(info_cmc, "df_modify", _("Modify Date Format"), offsetof(OptInfo, df_modify), sizeof info_options.df_modify);
