@@ -47,7 +47,7 @@ static void make_dir(MkdInfo *mdi)
 	gchar	buf[PATH_MAX];
 
 	g_snprintf(buf, sizeof buf, "%s%c%s", mdi->src->dir.path, G_DIR_SEPARATOR, gtk_entry_get_text(GTK_ENTRY(mdi->entry)));
-	if(mkdir(buf, -1) == 0)
+	if(mkdir(buf, 0755) == 0)
 	{
 		if(mkdir_options.cd_new)
 			csq_execute_format(mdi->src->main, "DirEnter 'dir=%s'", buf);
