@@ -34,7 +34,7 @@ typedef struct {
 
 static void ren_body(MainInfo *min, DirPane *src, DirRow *row, GtkWindow *win, gpointer user)
 {
-	gchar	temp[1024], *name;
+	gchar	temp[PATH_MAX + 256], *name;
 	RenInfo	*ren = (RenInfo *) user;
 
 	gtk_window_set_title(win, _("Rename"));
