@@ -91,7 +91,7 @@ int cmd_selectrow(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 	{
 		gint	col;
 
-		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_lines))
+		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_rows))
 			row = -1;
 	}
 
@@ -105,7 +105,6 @@ int cmd_selectrow(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 		afunc(src, row);
 		gtk_main_iteration();
 	}
-
 	return 1;
 }
 
@@ -139,7 +138,7 @@ int cmd_selecttoggle(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 	guint	i;
 
 	gtk_clist_freeze(src->list);
-	for(i = 0; i < src->dir.num_lines; i++)
+	for(i = 0; i < src->dir.num_rows; i++)
 		dp_toggle(src, i);
 	gtk_clist_thaw(src->list);
 	return 1;
@@ -156,7 +155,7 @@ static gboolean filter_set(DirPane *dp, guint row, SelParam *sp)
 
 	if(sp->set == SM_SET_ALL)
 		return TRUE;
-	sel = dp_is_selected(dp, &dp->dir.line[row]);
+	sel = dp_is_selected(dp, &dp->dir.row[row]);
 	return (sp->set == SM_SET_SELECTED) ? sel : !sel;
 }
 
@@ -167,7 +166,7 @@ static gboolean filter_type(DirPane *dp, guint row, SelParam *sp)
 
 	if(sp->type == SM_TYPE_ALL)
 		return TRUE;
-	dir = S_ISDIR(DP_ROW_LSTAT(&dp->dir.line[row]).st_mode);
+	dir = S_ISDIR(DP_ROW_LSTAT(&dp->dir.row[row]).st_mode);
 
 	return (sp->type == SM_TYPE_DIRS) ? dir : !dir;
 }
@@ -187,7 +186,6 @@ static guint compute_column(DirPane *dp, DPContent content)
 		if(dpf->format[i].content == content)
 			return i;
 	}
-
 	return 0;
 }
 
@@ -235,7 +233,7 @@ static void do_selectre(MainInfo *min, DirPane *dp, SelParam *sp)
 			dp_freeze(dp);
 			matchok = sp->invert ? REG_NOMATCH : 0;
 			column  = compute_column(dp, sp->content);
-			for(i = 0; i < dp->dir.num_lines; i++)
+			for(i = 0; i < dp->dir.num_rows; i++)
 			{
 				if(filter_set(dp, i, sp) && filter_type(dp, i, sp))
 				{
@@ -304,7 +302,6 @@ static GtkWidget * build_content_menu(DirPane *dp)
 		gtk_menu_append(GTK_MENU(menu), item);
 		gtk_widget_show(item);
 	}
-
 	return menu;
 }
 
@@ -478,16 +475,15 @@ int cmd_selectext(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 
 	for(iter = slist; iter != NULL; iter = g_slist_next(iter))
 	{
-		for(i = 0; i < src->dir.num_lines; i++)
+		for(i = 0; i < src->dir.num_rows; i++)
 		{
 			if(DP_SEL_INDEX(src, iter) == i)
 				continue;
 
-			if(stl_styleinfo_style_siblings(min->cfg.style, DP_SEL_TYPE(iter)->style, DP_ROW_TYPE(&src->dir.line[i])->style))
+			if(stl_styleinfo_style_siblings(min->cfg.style, DP_SEL_TYPE(iter)->style, DP_ROW_TYPE(&src->dir.row[i])->style))
 				dp_select(src, i);
 		}
 	}
-
 	dp_free_selection(slist);
 
 	return 1;
@@ -508,7 +504,7 @@ int cmd_selectsuffix(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 	{
 		gint	col;
 
-		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_lines))
+		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_rows))
 			row = -1;
 	}
 	else
@@ -524,13 +520,13 @@ int cmd_selectsuffix(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 		action = car_keyword_get_enum(ca, "action", 0, "select", "unselect", "toggle", NULL);
 		afunc = (action == 0) ? dp_select : (action == 1) ? dp_unselect : dp_toggle;
 
-		if((suff = stu_strcaserchr(DP_ROW_NAME(&src->dir.line[row]), '.')) != NULL)
+		if((suff = stu_strcaserchr(DP_ROW_NAME(&src->dir.row[row]), '.')) != NULL)
 		{
 			guint	i;
 
-			for(i = 0; i < src->dir.num_lines; i++)
+			for(i = 0; i < src->dir.num_rows; i++)
 			{
-				if(stu_has_suffix(DP_ROW_NAME(&src->dir.line[i]), suff))
+				if(stu_has_suffix(DP_ROW_NAME(&src->dir.row[i]), suff))
 					afunc(src, i);
 			}
 		}
@@ -552,7 +548,7 @@ int cmd_selecttype(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 	{
 		gint	col;
 
-		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_lines))
+		if(!gtk_clist_get_selection_info(GTK_CLIST(src->list), evt->x, evt->y, &row, &col) || (row > src->dir.num_rows))
 			row = -1;
 	}
 	else
@@ -564,13 +560,13 @@ int cmd_selecttype(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 		guint	action, i;
 		void	(*afunc)(DirPane *dp, gint row);
 
-		type   = DP_ROW_TYPE(&src->dir.line[row]);
+		type   = DP_ROW_TYPE(&src->dir.row[row]);
 		action = car_keyword_get_enum(ca, "action", 0, "select", "unselect", "toggle", NULL);
 		afunc  = (action == 0) ? dp_select : (action == 1) ? dp_unselect : dp_toggle;
 
-		for(i = 0; i < src->dir.num_lines; i++)
+		for(i = 0; i < src->dir.num_rows; i++)
 		{
-			if(DP_ROW_TYPE(&src->dir.line[i]) == type)
+			if(DP_ROW_TYPE(&src->dir.row[i]) == type)
 				afunc(src, i);
 		}
 	}
@@ -579,6 +575,54 @@ int cmd_selecttype(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
 
 /* ----------------------------------------------------------------------------------------- */
 
+#if 0
+struct cmp_rules {
+	gboolean	nocase;
+
+	gint		(*scmp)(const gchar *s1, const gchar *s2);
+};
+
+/* 2001-09-23 -	Compare <row> against all rows in <dst>, according to rules specified in <dr>.
+** 		Returns TRUE if there is a match, i.e. if a file named <row> exists in <dst>
+**		already.
+*/
+static gboolean cmp_exec(const DirRow *row, const DirPane *dst, const struct cmp_rules *dr)
+{
+	const gchar	*name;
+	gboolean	ret;
+	gint		i;
+	guint32		match;
+
+	name = DP_ROW_NAME(row);
+	for(i = 0; i < dst->dir.num_rows; i++)
+	{
+		if(dr->scmp(name, DP_ROW_NAME(&dst->dir.row[i])) != 0)
+			continue;
+		/* At this point, we have a name match. Furher requirements? */
+		return TRUE;
+	}
+	return FALSE;
+}
+
+int cmd_selectcmp(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca)
+{
+	static struct cmp_rules	rules = { FALSE };
+	gint			i;
+
+	/* Select string comparison function to use. */
+	rules.scmp  = rules.nocase ? stu_strcasecmp : strcmp;
+
+	for(i = 0; i < src->dir.num_rows; i++)
+	{
+		if(cmp_exec(&src->dir.row[i], dst, &rules))
+			dp_select(src, i);
+	}
+	return 1;
+}
+#endif
+
+/* ----------------------------------------------------------------------------------------- */
+
 /* 1998-09-20 -	The UnselectFirst command. In wrong module?
 ** 1998-12-16 -	This was freeze/thaw bracketed, for no good reason. Didn't work.
 */
