@@ -2,7 +2,7 @@
 ** 1999-05-06 -	Header for the built-in command argument parsing/handling module.
 */
 
-#if !defined(CMDARG_H)
+#if !defined CMDARG_H
 #define	CMDARG_H
 
 /* An opaque type that acts as a "handle" on the arguments given to a command. */
