@@ -25,13 +25,6 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* I can never be trusted to remember which end of a pipe is which, so these
-** three really help out. Er, of course only the first two apply to pipes.
-*/
-#define	FD_INPUT	(0)
-#define	FD_OUTPUT	(1)
-#define	FD_ERROR	(2)
-
 #define	GRAB_CHUNK	(32768)		/* We read this many bytes on each "input available" callback. */
 
 typedef struct {
@@ -77,13 +70,13 @@ void cgr_set_child_pipes(MainInfo *min, CmdRow *row, int fd_out[2], int fd_err[2
 {
 	if(row->type == CRTP_EXTERNAL && row->extra.external.gflags & CGF_GRABOUTPUT)
 	{
-		assert(close(FD_OUTPUT) == 0);
-		assert(dup(fd_out[FD_OUTPUT]) == FD_OUTPUT);
-		assert(close(fd_out[FD_INPUT]) == 0);
+		assert(close(STDOUT_FILENO) == 0);
+		assert(dup(fd_out[STDOUT_FILENO]) == STDOUT_FILENO);
+		assert(close(fd_out[STDIN_FILENO]) == 0);
 
-		assert(close(FD_ERROR) == 0);
-		assert(dup(fd_err[FD_OUTPUT]) == FD_ERROR);
-		assert(close(fd_err[FD_INPUT]) == 0);
+		assert(close(STDERR_FILENO) == 0);
+		assert(dup(fd_err[STDOUT_FILENO]) == STDERR_FILENO);
+		assert(close(fd_err[STDIN_FILENO]) == 0);
 	}
 }
 
@@ -133,8 +126,8 @@ static gint evt_grab_keypress(GtkWidget *wid, GdkEventKey *event, gpointer user)
 */
 static void grab_callback(gpointer data, gint fd, GdkInputCondition cond)
 {
-	char		buf[GRAB_CHUNK];
-	int		got;
+	gchar		buf[GRAB_CHUNK];
+	gint		got;
 	GrabInfo	*gri = (GrabInfo *) data;
 
 	if(cond & GDK_INPUT_READ)
@@ -169,7 +162,6 @@ static void grab_callback(gpointer data, gint fd, GdkInputCondition cond)
 			close(gri->fd_err);
 			gri->fd_err = -1;
 		}
-
 		if((gri->fd_out == -1) && (gri->fd_err == -1))	/* Both channels closed down? */
 		{
 			if(gri->txv != NULL)			/* Window still open? */
@@ -189,9 +181,9 @@ static void grab_callback(gpointer data, gint fd, GdkInputCondition cond)
 /* 1998-09-26 -	Set up two GTK+ input listeners, one on <fd_out> and one on <fd_err>. Is
 **		cool (?) enough to share a single output window between these two channels.
 */
-static void grab_output(MainInfo *min, char *prog, pid_t child, int fd_out, int fd_err)
+static void grab_output(MainInfo *min, const gchar *prog, pid_t child, int fd_out, int fd_err)
 {
-	char		buf[MAXNAMLEN + 32];
+	gchar		buf[MAXNAMLEN + 32];
 	GrabInfo	*gri;
 
 	gri = g_malloc(sizeof *gri);
@@ -217,8 +209,8 @@ void cgr_set_parent_pipes(MainInfo *min, CmdRow *row, char *prog, int child, int
 {
 	if(row->type == CRTP_EXTERNAL && row->extra.external.gflags & CGF_GRABOUTPUT)
 	{
-		assert(close(fd_out[FD_OUTPUT]) == 0);
-		assert(close(fd_err[FD_OUTPUT]) == 0);
-		grab_output(min, prog, child, fd_out[FD_INPUT], fd_err[FD_INPUT]);
+		assert(close(fd_out[STDOUT_FILENO]) == 0);
+		assert(close(fd_err[STDOUT_FILENO]) == 0);
+		grab_output(min, prog, child, fd_out[STDIN_FILENO], fd_err[STDIN_FILENO]);
 	}
 }
