@@ -110,8 +110,7 @@ static void parse_code_file(MainInfo *min, GString *cstr, char *code)
 			break;
 	}
 	if(cnt > 0)
-		g_string_truncate(cstr, cstr->len - 1);		/* Loose last space. */
-
+		g_string_truncate(cstr, cstr->len - 1);		/* Lose last space. */
 	dp_free_selection(slist);
 }
 
@@ -120,8 +119,8 @@ static void parse_code_file(MainInfo *min, GString *cstr, char *code)
 */
 static void parse_code_path(MainInfo *min, GString *cstr, char *code)
 {
-	char	*path = NULL;
-	DirPane	*src = min->gui->cur_pane, *dst = dp_mirror(min, src);
+	const gchar	*path = NULL;
+	DirPane		*src = min->gui->cur_pane, *dst = dp_mirror(min, src);
 
 	if(code[1] == '\0')			/* Nothing but the 'P'? */
 		path = src->dir.path;
@@ -232,13 +231,18 @@ static gint evt_input_string_visible(GtkWidget *wid, gpointer user)
 /* 1998-09-25 -	Build a string widget for an input dialog. Cut-down version.
 ** 1999-02-27 -	Modified for the new packing scheme.
 */
-static gint build_input_string(CmdDlg *dlg, gchar *def, CmdInp *inp)
+static gint build_input_string(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 {
 	GtkWidget	*ent;
 	gchar		*end;
 
 	inp->type = CITP_STRING;
 	ent = gtk_entry_new();
+	if(*def == '*')	/* Password mode? */
+	{
+		gtk_entry_set_visibility(GTK_ENTRY(ent), FALSE);
+		def++;
+	}
 	if(*def == '=' && def[1] == '"')
 	{
 		if((end = strchr(def + 2, '"')) != NULL)
@@ -350,7 +354,7 @@ static gint build_input_combo(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 **		only *set* by {It...}, not created. Now {It...} creates and packs another label,
 **		or even a separator (if the code is {It:-}).
 */
-static gint build_input_label(CmdDlg *dlg, gchar *def, CmdInp *inp)
+static gint build_input_label(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 {
 	if(def != NULL)
 	{
@@ -374,7 +378,7 @@ static gint build_input_label(CmdDlg *dlg, gchar *def, CmdInp *inp)
 **		the label on the left side. A pressed-in ("checked") box generates TRUE, a non-
 **		checked box emits a FALSE.
 */
-static gint build_input_checkbox(CmdDlg *dlg, gchar *label, gchar *def, CmdInp *inp)
+static gint build_input_checkbox(CmdDlg *dlg, const gchar *label, const gchar *def, CmdInp *inp)
 {
 	if(def != NULL)
 	{
@@ -392,7 +396,8 @@ static gint build_input_checkbox(CmdDlg *dlg, gchar *label, gchar *def, CmdInp *
 */
 static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *dlg)
 {
-	gchar		*ltxt = NULL, *end, *def = code + 1;
+	gchar		*ltxt = NULL, *end;
+	const gchar	*def = code + 1;
 	gint		succ = 0;
 	GtkWidget	*label;
 
@@ -413,6 +418,8 @@ static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *
 				ltxt = NULL;
 		}
 	}
+	else
+		def++;
 
 	switch(code[1])
 	{
@@ -460,7 +467,7 @@ static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *
 }
 
 /* 1998-09-25 -	Get a pointer to a string representation of row <row> in dialog <dlg>. */
-static char * eval_input(CmdDlg *dlg, int row)
+static gchar * eval_input(CmdDlg *dlg, gint row)
 {
 	GList	*data;
 
@@ -473,11 +480,11 @@ static char * eval_input(CmdDlg *dlg, int row)
 			case CITP_MENU:
 				if((data = g_list_nth(dlg->input[row].inp.menu.items, dlg->input[row].inp.menu.current)) != NULL)
 				{
-					char	*colon;
+					gchar	*colon;
 
 					if((colon = strchr((char *) data->data, ':')) != NULL)
 						return colon + 1;
-					return (char *) data->data;
+					return (gchar *) data->data;
 				}
 				return NULL;
 			case CITP_COMBO:
@@ -556,7 +563,7 @@ static void destroy_input(CmdDlg *dlg)
 /* 1998-09-25 -	Parse a word that contains 1 or more special "brace-codes". The codes need
 **		to be replaced by a value, or an input-dialog place holder.
 */
-static void parse_code(MainInfo *min, GString *cstr, char *code, CmdDlg *dlg)
+static void parse_code(MainInfo *min, GString *cstr, gchar *code, CmdDlg *dlg)
 {
 	if(code == NULL || cstr == NULL || dlg == NULL)
 		return;
@@ -717,7 +724,7 @@ gchar ** cpr_parse(MainInfo *min, const gchar *def)
 ** 1999-02-24 -	Thanks to the allocation intelligence of the new stu_split_args() routine, this
 **		has considerably less to do. Fine by me.
 */
-void cpr_free(char **argv)
+void cpr_free(gchar **argv)
 {
 	if(argv != NULL)
 		g_free(argv);
