@@ -56,7 +56,7 @@ void csq_add_builtin(MainInfo *min, const gchar *name, Command cmd, CommandCfg c
 	if(cfg->commands.builtin == NULL)
 		cfg->commands.builtin = g_hash_table_new(g_str_hash, g_str_equal);
 	if(builtin_chunk == NULL)
-		builtin_chunk = g_mem_chunk_new("CmdDesc", sizeof(CmdDesc), 64, G_ALLOC_ONLY);
+		builtin_chunk = g_mem_chunk_new("CmdDesc", sizeof (CmdDesc), 64, G_ALLOC_ONLY);
 	if((cfg->commands.builtin != NULL) && (builtin_chunk != NULL))
 	{
 		CmdDesc	*cdesc;
@@ -406,7 +406,7 @@ void csq_handle_ba_flags(MainInfo *min, guint32 flags)
 ** 1998-09-25 -	Moved into the new cmdseq module, and adapted accordingly.
 ** 1999-05-29 -	Added pre-fork() protection through new call in fileutil module. Very nice.
 */
-static int fork_and_execute(MainInfo *min, CmdRow *row, char **argv)
+static int fork_and_execute(MainInfo *min, CmdRow *row, gchar **argv)
 {
 	pid_t	child;
 	int	estat, fd_out[2], fd_err[2];
@@ -433,8 +433,8 @@ static int fork_and_execute(MainInfo *min, CmdRow *row, char **argv)
 		{
 			cgr_set_child_pipes(min, row, fd_out, fd_err);
 			estat = execvp(argv[0], argv);
-			perror("execvp() returned");
-			exit(EXIT_FAILURE);
+			usleep(50000);				/* Someone, sue me. */
+			_exit(CHD_EXIT_FAILURE);
 		}
 		else			/* In parent. */
 		{
@@ -728,6 +728,7 @@ void csq_init_commands(MainInfo *min)
 	csq_add_builtin(min, "Delete",		cmd_delete,		NULL);
 	csq_add_builtin(min, "Rename",		cmd_rename,		NULL);
 	csq_add_builtin(min, "RenameRE",	cmd_renamere,		NULL);
+	csq_add_builtin(min, "RenameSeq",	cmd_renameseq,		NULL);
 	csq_add_builtin(min, "ChMod",		cmd_chmod,		NULL);
 	csq_add_builtin(min, "ChOwn",		cmd_chown,		NULL);
 	csq_add_builtin(min, "Split",		cmd_split,		NULL);
@@ -754,6 +755,7 @@ void csq_init_commands(MainInfo *min)
 	csq_add_builtin(min, "SelectExt",	cmd_selectext,		NULL);
 	csq_add_builtin(min, "SelectType",	cmd_selecttype,		NULL);
 	csq_add_builtin(min, "SelectSuffix",	cmd_selectsuffix,	NULL);
+/*	csq_add_builtin(min, "SelectCmp",	cmd_selectcmp,		NULL);*/
 	csq_add_builtin(min, "UnselectFirst",	cmd_unselectfirst,	NULL);
 
 	csq_add_builtin(min, "Information",	cmd_information,	cfg_information);
