@@ -136,7 +136,7 @@ void cmc_config_base_save(CmdCfg *cmc, FILE *out)
 }
 
 /* 1999-04-05 -	Load (parse) data from <node> into the base instance of <cmc>. */
-void cmc_config_base_load(CmdCfg *cmc, XmlNode *node)
+void cmc_config_base_load(CmdCfg *cmc, const XmlNode *node)
 {
 	if((cmc != NULL) && (node != NULL))
 	{
@@ -639,19 +639,19 @@ gpointer cmc_instance_new(CmdCfg *cmc)
 			switch(fld->type)
 			{
 				case CFT_INTEGER:
-					fsize += sizeof(gint);
+					fsize += sizeof (gint);
 					break;
 				case CFT_BOOLEAN:
-					fsize += sizeof(gboolean);
+					fsize += sizeof (gboolean);
 					break;
 				case CFT_SIZE:
-					fsize += sizeof(gsize);
+					fsize += sizeof (gsize);
 					break;
 				case CFT_STRING:
 					fsize += fld->field.string.size;
 					break;
 				case CFT_COLOR:
-					fsize += sizeof(GdkColor);
+					fsize += sizeof (GdkColor);
 					break;
 			}
 			if(fsize > size)
