@@ -412,7 +412,7 @@ void ctrl_keys_uninstall_all(CtrlInfo *ctrl)
 
 static gint cmp_string(gconstpointer a, gconstpointer b)
 {
-	return strcmp((char *) a, (char *) b);
+	return strcmp(a, b);
 }
 
 static void key_insert(gpointer key, gpointer value, gpointer user)
@@ -462,7 +462,7 @@ static void mouse_destroy(CtrlMouse *cm)
 /* 1999-06-12 -	Compare two mouse command definitions, ordering them in mouse button order. */
 static gint mouse_cmp(gconstpointer a, gconstpointer b)
 {
-	CtrlMouse	*ma = (CtrlMouse *) a, *mb = (CtrlMouse *) b;
+	const CtrlMouse	*ma = a, *mb = b;
 
 	if(ma->button == mb->button)
 		return ma->state - mb->state;
@@ -569,8 +569,8 @@ const gchar * ctrl_mouse_map(CtrlInfo *ctrl, GdkEventButton *evt)
 		guint		state;
 
 		state = evt->state;
-		if(ctrl->nonumlock)
-			state &= ~GDK_MOD2_MASK;
+		/* Allow only the modifiers known to be configurable for mouse buttons. */
+		state &= (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK);
 
 		for(iter = ctrl->mouse; iter != NULL; iter = g_list_next(iter))
 		{
