@@ -4,7 +4,7 @@
 **		architecture are simply being rolled over. Or something.
 */
 
-#if !defined(CONTROLS_H)
+#if !defined CONTROLS_H
 #define	CONTROLS_H
 
 typedef struct CtrlInfo		CtrlInfo;
