@@ -2,7 +2,7 @@
 ** 1998-11-26 -	Header for the directory history handling module. Mainly called from the dirpane module.
 */
 
-#if !defined(DIRHISTORY_H)
+#if !defined DIRHISTORY_H
 #define	DIRHISTORY_H
 
 /* ----------------------------------------------------------------------------------------- */
