@@ -26,7 +26,6 @@
 
 #include "errors.h"
 #include "dpformat.h"
-#include "dpmenu.h"
 #include "fileutil.h"
 #include "userinfo.h"
 #include "cmdseq.h"
@@ -48,7 +47,7 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-static DPSort	the_sort;			/* Used to get state across to callback. */
+static DPSort	the_sort;			/* Used to get state across to qsort() callback. */
 static gint	(*the_strcmp)(const gchar *a, const gchar *b);
 
 static GtkStyle	*pane_selected = NULL,		/* The style used on selected pane's column buttons. */
@@ -93,9 +92,9 @@ const gchar * dp_full_name(DirPane *dp, gint row)
 	static gchar	buf[PATH_MAX];
 
 	if((dp->dir.path[0] == G_DIR_SEPARATOR) && (dp->dir.path[1] == '\0'))	/* Faster than strcmp(path, "/")? ;^) */
-		g_snprintf(buf, sizeof buf, "/%s", DP_ROW_NAME(&dp->dir.line[row]));
+		g_snprintf(buf, sizeof buf, "/%s", DP_ROW_NAME(&dp->dir.row[row]));
 	else
-		g_snprintf(buf, sizeof buf, "%s/%s", dp->dir.path, DP_ROW_NAME(&dp->dir.line[row]));
+		g_snprintf(buf, sizeof buf, "%s/%s", dp->dir.path, DP_ROW_NAME(&dp->dir.row[row]));
 	return buf;
 }
 
@@ -109,7 +108,7 @@ const gchar * dp_name_quoted(DirPane *dp, gint row, guint path)
 	const gchar	*fn, *ptr;
 	gchar		*put = buf;
 
-	fn = path ? dp_full_name(dp, row) : DP_ROW_NAME(&dp->dir.line[row]);
+	fn = path ? dp_full_name(dp, row) : DP_ROW_NAME(&dp->dir.row[row]);
 	*put++ = '"';
 	for(ptr = fn; *ptr; ptr++)
 	{
@@ -183,7 +182,7 @@ static gboolean evt_path_key_press(GtkWidget *wid, GdkEventKey *evt, gpointer us
 
 		printf("It's a TAB!\n");
 		text = gtk_entry_get_text(GTK_ENTRY(wid));
-		g_snprintf(buf, sizeof buf, "%s", text);
+		stu_strncpy(buf, text, sizeof buf);
 		buf[GTK_EDITABLE(wid)->current_pos] = '\0';
 		printf(" Trying to complete '%s'\n", buf);
 		if(glob(buf, GLOB_ERR | GLOB_MARK, NULL, &globbuf) == 0)
@@ -264,7 +263,7 @@ void dp_freeze(DirPane *dp)
 */
 void dp_thaw(DirPane *dp)
 {
-	int	old_errno = errno;
+	gint	old_errno = errno;
 
 	gtk_clist_thaw(GTK_CLIST(dp->list));
 	errno = old_errno;
@@ -304,10 +303,18 @@ void dp_select(DirPane *dp, gint row)
 
 /* 1999-03-04 -	Select all rows. Handy for the SelectAll command. Since selection management
 **		is now largely done by the GtkCList widget for us, this is not rocket science.
+** 2000-09-16 -	Noticed that using gtk_clist_select_all() reset the vertical scroll of the list
+**		to zero, which annoyed me. This happens regardless of callback. Did a work around.
 */
 void dp_select_all(DirPane *dp)
 {
-	gtk_clist_select_all(GTK_CLIST(dp->list));
+	gint	i;
+
+/*	gtk_clist_select_all(GTK_CLIST(dp->list));*/		/* FIXME: Should be faster. GTK+ bug? */
+	dp_freeze(dp);
+	for(i = 0; i < dp->dir.num_rows; i++)
+		gtk_clist_select_row(GTK_CLIST(dp->list), i, -1);
+	dp_thaw(dp);
 }
 
 /* 1999-03-04 -	Rewritten in a lot simpler way. */
@@ -323,7 +330,9 @@ void dp_unselect(DirPane *dp, gint row)
 void dp_unselect_all(DirPane *dp)
 {
 	dp->dbclk_row = -1;
-	gtk_clist_unselect_all(GTK_CLIST(dp->list));
+	dp_freeze(dp);
+	gtk_clist_unselect_all(GTK_CLIST(dp->list));		/* FIXME: This takes ages on large selections. */
+	dp_thaw(dp);
 }
 
 /* 2000-03-18 -	Since the select/unselect functions no longer return success or failure, the check
@@ -346,13 +355,13 @@ static void focus_select(DirPane *dp, gint row)
 }
 
 /* 1999-03-04 -	A row in the pane was selected. Update statistics. */
-static gint evt_dirpane_select_row(GtkWidget *wid, gint row, gint col, GdkEventButton *ev, gpointer data)
+static void evt_dirpane_select_row(GtkWidget *wid, gint row, gint col, GdkEventButton *ev, gpointer data)
 {
 	DirPane	*dp = data;
 	DirRow	*dr;
 
 	if((dr = gtk_clist_get_row_data(GTK_CLIST(wid), row)) == NULL)
-		return FALSE;
+		return;
 
 	if(S_ISDIR(DP_ROW_LSTAT(dr).st_mode))
 		dp->dir.sel.num_dirs++;
@@ -367,8 +376,6 @@ static gint evt_dirpane_select_row(GtkWidget *wid, gint row, gint col, GdkEventB
 
 	if(dp->dbclk_row == row)
 		dp_dbclk(dp);
-
-	return FALSE;
 }
 
 /* 1999-03-04 -	A row has been unselected, so we need to update our statistics.
@@ -376,7 +383,7 @@ static gint evt_dirpane_select_row(GtkWidget *wid, gint row, gint col, GdkEventB
 **		clicked row is no longer selected (dp_get_selection() will not include it),
 **		which is very important, for example for the directory history.
 */
-static gint evt_dirpane_unselect_row(GtkWidget *wid, gint row, gint col, GdkEventButton *ev, gpointer data)
+static void evt_dirpane_unselect_row(GtkWidget *wid, gint row, gint col, GdkEventButton *ev, gpointer data)
 {
 	DirPane	*dp = data;
 
@@ -385,8 +392,6 @@ static gint evt_dirpane_unselect_row(GtkWidget *wid, gint row, gint col, GdkEven
 
 	if(dp->dbclk_row >= 0)		/* Did a double-click occur resently? */
 		dp_dbclk(dp);
-
-	return FALSE;
 }
 
 /* 1999-03-05 -	Update the state of the GDK_CONTROL_MASK bitmask in <state>, depending on how
@@ -421,9 +426,8 @@ static guint update_ctrl_state(DirPane *dp, guint state)
 **		is so supported. But, nice never the less (and somewhat standard, so people might expect it).
 ** 1998-06-17 -	Added control-sensing to "extend" the current UNselection. Cool?
 ** 1999-03-05 -	Simplified since we now use GTK+'s built-in CList selection.
-** 1999-06-12 -	Further simplifications and forshortenings due to new 
 */
-static void evt_dirpane_button_press(GtkWidget *wid, GdkEventButton *event, gpointer user)
+static gboolean evt_dirpane_button_press(GtkWidget *wid, GdkEventButton *event, gpointer user)
 {
 	const gchar	*mcmd;
 	gint		ret, row, col;
@@ -442,11 +446,11 @@ static void evt_dirpane_button_press(GtkWidget *wid, GdkEventButton *event, gpoi
 		csq_execute(dp->main, mcmd);
 		evt_event_clear(event->type);
 		gtk_signal_emit_stop_by_name(GTK_OBJECT(dp->list), "button_press_event");
-		return;
+		return TRUE;
 	}
 
 	ret = gtk_clist_get_selection_info(GTK_CLIST(wid), (gint) event->x, (gint) event->y, &row, &col);
-	if(ret && (row < dp->dir.num_lines))
+	if(ret && (row < dp->dir.num_rows))
 	{
 		if((event->type == GDK_2BUTTON_PRESS) && (row == dp->last_row2))
 		{
@@ -473,6 +477,8 @@ static void evt_dirpane_button_press(GtkWidget *wid, GdkEventButton *event, gpoi
 	}
 	else
 		dp->last_row = dp->last_row2 = -1;
+
+	return TRUE;
 }
 
 static void evt_dirpane_col_click(GtkWidget *wid, gint column, gpointer user)
@@ -499,26 +505,6 @@ static void evt_dirpane_col_click(GtkWidget *wid, gint column, gpointer user)
 	}
 }
 
-void evt_dirpane_menu(GtkWidget *wid, gpointer user)
-{
-	MainInfo	*min;
-
-	if((min = gtk_object_get_user_data(GTK_OBJECT(wid))) != NULL)
-	{
-		gchar	*action;
-
-		if((action = gtk_object_get_data(GTK_OBJECT(wid), "action")) != NULL)
-		{
-			gchar	buf[1024];
-
-			g_snprintf(buf, sizeof buf, "FileAction action=%s", action);
-			csq_execute(min, buf);
-		}
-		else
-			csq_execute(min, (const gchar *) user);
-	}
-}
-
 /* 1999-05-15 -	User resized a column. Update format. I hope this is a new signal... */
 static void evt_dirpane_resize_column(GtkWidget *wid, gint column, gint width, gpointer user)
 {
@@ -711,45 +697,26 @@ static sorter choose_sorter(DirPane *dp)
 {
 	switch(dp->main->cfg.dp_format[dp->index].sort.content)
 	{
-		case DPC_NAME:
-			return qsort_cmp_name;
-		case DPC_SIZE:
-			return qsort_cmp_size;
-		case DPC_IQSIZE:
-			return qsort_cmp_iqsize;
-		case DPC_BLOCKS:
-			return qsort_cmp_blocks;
-		case DPC_BLOCKSIZE:
-			return qsort_cmp_blocks;
-		case DPC_MODENUM:
-		case DPC_MODESTR:
-			return qsort_cmp_modeoct;
-		case DPC_NLINK:
-			return qsort_cmp_nlink;
-		case DPC_UIDNUM:
-			return qsort_cmp_uiddec;
-		case DPC_UIDSTR:
-			return qsort_cmp_uidstr;
-		case DPC_GIDNUM:
-			return qsort_cmp_giddec;
-		case DPC_GIDSTR:
-			return qsort_cmp_gidstr;
-		case DPC_DEVICE:
-			return qsort_cmp_dev;
-		case DPC_DEVMAJ:
-			return qsort_cmp_devmaj;
-		case DPC_DEVMIN:
-			return qsort_cmp_devmin;
-		case DPC_ATIME:
-			return qsort_cmp_atime;
-		case DPC_MTIME:
-			return qsort_cmp_mtime;
-		case DPC_CTIME:
-			return qsort_cmp_ctime;
-		case DPC_TYPE:
-			return qsort_cmp_type;
-		case DPC_ICON:
-			return qsort_cmp_style;
+		case DPC_NAME:			return qsort_cmp_name;
+		case DPC_SIZE:			return qsort_cmp_size;
+		case DPC_IQSIZE:		return qsort_cmp_iqsize;
+		case DPC_BLOCKS:		return qsort_cmp_blocks;
+		case DPC_BLOCKSIZE:		return qsort_cmp_blocks;
+		case DPC_MODENUM:	/* Fall-through. */
+		case DPC_MODESTR:		return qsort_cmp_modeoct;
+		case DPC_NLINK:			return qsort_cmp_nlink;
+		case DPC_UIDNUM:		return qsort_cmp_uiddec;
+		case DPC_UIDSTR:		return qsort_cmp_uidstr;
+		case DPC_GIDNUM:		return qsort_cmp_giddec;
+		case DPC_GIDSTR:		return qsort_cmp_gidstr;
+		case DPC_DEVICE:		return qsort_cmp_dev;
+		case DPC_DEVMAJ:		return qsort_cmp_devmaj;
+		case DPC_DEVMIN:		return qsort_cmp_devmin;
+		case DPC_ATIME:			return qsort_cmp_atime;
+		case DPC_MTIME:			return qsort_cmp_mtime;
+		case DPC_CTIME:			return qsort_cmp_ctime;
+		case DPC_TYPE:			return qsort_cmp_type;
+		case DPC_ICON:			return qsort_cmp_style;
 
 		case DPC_NUM_TYPES:
 			;
@@ -772,7 +739,7 @@ static gint numeric_strcmp(const gchar *a, const gchar *b)
 			an = strtol(a, &a_end, 10);
 			bn = strtol(b, &b_end, 10);
 			if(an != bn)
-				return an - bn;		/* This has a certain chance to overflow. Let's assume people only use "small" ints in their names. :) */
+				return (an < bn) ? -1 : an > bn;
 			a = a_end;
 			b = b_end;
 		}
@@ -799,7 +766,7 @@ static gint numeric_strcasecmp(const gchar *a, const gchar *b)
 			an = strtol(a, &aend, 10);
 			bn = strtol(b, &bend, 10);
 			if(an != bn)
-				return an - bn;
+				return (an < bn) ? -1 : an > bn;
 			a = aend;
 			b = bend;
 		}
@@ -821,10 +788,10 @@ void dp_resort(DirPane *dp)
 	guint	i;
 
 	/* "NULL out" any non-link stat fields, to avoid breaking links during resorting. */
-	for(i = 0; i < dp->dir.num_lines; i++)
+	for(i = 0; i < dp->dir.num_rows; i++)
 	{
-		if(DP_ROW_GET_STAT(dp->dir.line + i) == &DP_ROW_LSTAT(dp->dir.line + i))
-			DP_ROW_SET_STAT(dp->dir.line + i, NULL);
+		if(DP_ROW_GET_STAT(dp->dir.row + i) == &DP_ROW_LSTAT(dp->dir.row + i))
+			DP_ROW_SET_STAT(dp->dir.row + i, NULL);
 	}
 
 	the_sort = dp->main->cfg.dp_format[dp->index].sort;	/* Must be accessible by qsort() callbacks. */
@@ -833,13 +800,13 @@ void dp_resort(DirPane *dp)
 			the_sort.nocase ? stu_strcasecmp : strcmp;
 
 	/* Resort the DirRow structures. */
-	qsort(dp->dir.line, dp->dir.num_lines, sizeof *dp->dir.line, choose_sorter(dp));
+	qsort(dp->dir.row, dp->dir.num_rows, sizeof *dp->dir.row, choose_sorter(dp));
 
 	/* Now re-connect any NULL stat links, thus making them point at the lstat fields again. */
-	for(i = 0; i < dp->dir.num_lines; i++)
+	for(i = 0; i < dp->dir.num_rows; i++)
 	{
-		if(DP_ROW_GET_STAT(dp->dir.line + i) == NULL)
-			DP_ROW_SET_STAT(dp->dir.line + i, &DP_ROW_LSTAT(dp->dir.line + i));
+		if(DP_ROW_GET_STAT(dp->dir.row + i) == NULL)
+			DP_ROW_SET_STAT(dp->dir.row + i, &DP_ROW_LSTAT(dp->dir.row + i));
 	}
 }
 
@@ -852,22 +819,20 @@ void dp_resort(DirPane *dp)
 */
 void dp_redisplay(DirPane *dp)
 {
-	gchar		buffer[DP_MAX_COLUMNS][2 * PATH_MAX];
-	gchar		*buf[DP_MAX_COLUMNS];
-	gint		row;
-	guint		i, j;
+	gchar	buffer[DP_MAX_COLUMNS][2 * PATH_MAX], *buf[DP_MAX_COLUMNS];
+	guint	i, j, row;
 
 	dp_freeze(dp);						/* Reduce ugly flicker. */
 	gtk_clist_clear(dp->list);				/* Remove any old entries. */
 
 	for(i = 0; i < sizeof buf / sizeof buf[0]; i++)
 		buf[i] = &buffer[i][0];
-	for(i = 0; i < dp->dir.num_lines; i++)
+	for(i = 0; i < dp->dir.num_rows; i++)
 	{
 		for(j = 0; j < dp->main->cfg.dp_format[dp->index].num_columns; j++)
-			dpf_format_column(dp->main, dp, &dp->dir.line[i], j, buf[j]);
+			dpf_format_column(dp->main, dp, &dp->dir.row[i], j, buf[j]);
 		row = gtk_clist_append(dp->list, buf);
-		gtk_clist_set_row_data(GTK_CLIST(dp->list), row, &dp->dir.line[i]);
+		gtk_clist_set_row_data(GTK_CLIST(dp->list), row, &dp->dir.row[i]);
 		dpf_post_format_row(dp->main, dp, row);
 	}
 	dp_thaw(dp);
@@ -920,7 +885,7 @@ void dp_focus(DirPane *dp, gint row)
 
 	dp_unfocus(dp);
 
-	if((row < 0) || (row >= dp->dir.num_lines))
+	if((row < 0) || (row >= dp->dir.num_rows))
 	{
 		dp->focus_row = -1;
 		return;
@@ -1098,7 +1063,7 @@ GSList * dp_get_selection_full(DirPane *dp)
 	return sel;
 }
 
-#if 0		/* dp_print_selection() */
+#if 0
 /* 1999-03-05 -	A little routine handy for debugging. */
 void dp_print_selection(DirPane *dp, char *tag)
 {
@@ -1153,7 +1118,7 @@ static void clear_total_stats(DirPane *dp)
 /* 1999-01-03 -	Clear the statistics for <dp>. Useful when the pane's path is about to change. */
 static void clear_stats(DirPane *dp)
 {
-	dp->dir.num_lines = 0;
+	dp->dir.num_rows = 0;
 
 	clear_total_stats(dp);
 	clear_selection_stats(&dp->dir.sel);
@@ -1193,9 +1158,9 @@ void dp_update_stats(DirPane *dp)
 
 	clear_total_stats(dp);
 	clear_selection_stats(&dp->dir.sel);
-	for(i = 0; i < dp->dir.num_lines; i++)
+	for(i = 0; i < dp->dir.num_rows; i++)
 	{
-		dr = &dp->dir.line[i];
+		dr = &dp->dir.row[i];
 
 		if(S_ISDIR(DP_ROW_LSTAT(dr).st_mode))
 			dp->dir.tot_dirs++;
@@ -1211,7 +1176,7 @@ static void update_fs_info(DirPane *dp)
 {
 	int	old_errno = errno;
 
-#if defined(__linux) || defined(__OpenBSD__) || defined(__FreeBSD__)
+#if defined __linux || defined __OpenBSD__ || defined __FreeBSD__ || defined __NetBSD__
 	dp->dir.fs.valid = (statfs(dp->dir.path, &dp->dir.fs.stat) == 0);
 #else
 	dp->dir.fs.valid = (statvfs(dp->dir.path, &dp->dir.fs.stat) == 0);
@@ -1282,10 +1247,10 @@ void dp_enter_dir(DirPane *dp, const gchar *path)
 		dp->focus_row = -1;
 		if(num == 0)			/* Treat empty directories specially. */
 		{
-			if(dp->dir.line != NULL)
+			if(dp->dir.row != NULL)
 			{
-				g_free(dp->dir.line);
-				dp->dir.line = NULL;
+				g_free(dp->dir.row);
+				dp->dir.row = NULL;
 			}
 			if(dp->dir.auxbuf != NULL)
 			{
@@ -1295,7 +1260,7 @@ void dp_enter_dir(DirPane *dp, const gchar *path)
 		}
 		else
 		{
-			dp->dir.line   = g_realloc(dp->dir.line, num * sizeof *dp->dir.line);
+			dp->dir.row    = g_realloc(dp->dir.row, num * sizeof *dp->dir.row);
 			dp->dir.auxbuf = g_realloc(dp->dir.auxbuf, auxsize);
 			if((dir = opendir(".")) != NULL)
 			{
@@ -1304,7 +1269,7 @@ void dp_enter_dir(DirPane *dp, const gchar *path)
 				DirRow		*row;
 
 				typ_identify_begin(dp->main);
-				for(row = dp->dir.line; ((de = readdir(dir)) != NULL);)
+				for(row = dp->dir.row; ((de = readdir(dir)) != NULL);)
 				{
 					if(!(dp->main->cfg.dir_filter(de->d_name) && fut_check_hide(dp, de->d_name)))
 						continue;
@@ -1342,7 +1307,7 @@ void dp_enter_dir(DirPane *dp, const gchar *path)
 					}
 				}
 				typ_identify_end(dp->main, dp->dir.path);
-				dp->dir.num_lines = row - dp->dir.line;
+				dp->dir.num_rows = row - dp->dir.row;
 				closedir(dir);
 			}
 		}
@@ -1430,7 +1395,6 @@ GtkWidget * dp_build(MainInfo *min, DPFormat *fmt, DirPane *dp)
 		gtk_style_unref(focus_style);
 		focus_style = NULL;
 	}
-
 	if(dp == NULL)
 		return NULL;
 
@@ -1522,7 +1486,10 @@ GtkWidget * dp_build(MainInfo *min, DPFormat *fmt, DirPane *dp)
 		dp->focus_row = -1;
 		dp->old_focus_row = -1;
 
+/* FIXME: This should probably just go away, and leave room for the
+**	  new generalized menu system.
 		dpm_initialize(dp);
+*/
 	}
 	return dp->vbox;
 }
