@@ -474,10 +474,10 @@ void dpf_post_format_row(MainInfo *min, DirPane *dp, gint row)
 	GdkBitmap	*imsk;
 
 	fmt = &min->cfg.dp_format[dp->index];
-	stl = DP_ROW_TYPE(&dp->dir.line[row])->style;
+	stl = DP_ROW_TYPE(&dp->dir.row[row])->style;
 	if(stl == NULL)
 	{
-		fprintf(stderr, "DPFORMAT: No style for '%s'\n", DP_ROW_NAME(&dp->dir.line[row]));
+		fprintf(stderr, "DPFORMAT: No style for '%s'\n", DP_ROW_NAME(&dp->dir.row[row]));
 		return;
 	}
 
@@ -501,7 +501,7 @@ void dpf_format_colors_row(DirPane *dp, gint row)
 {
 	Style	*stl;
 
-	stl = DP_ROW_TYPE(&dp->dir.line[row])->style;
+	stl = DP_ROW_TYPE(&dp->dir.row[row])->style;
 
 	gtk_clist_set_background(GTK_CLIST(dp->list), row, (GdkColor *) stl_style_property_get_color(stl, SPN_COL_UNSEL_BG));
 	gtk_clist_set_foreground(GTK_CLIST(dp->list), row, (GdkColor *) stl_style_property_get_color(stl, SPN_COL_UNSEL_FG));
