@@ -367,7 +367,7 @@ static void eval_home(gchar *component)
 **		<paths> is NULL, with the _next_ component (relative to the last one). If this sounds
 **		confusing, read the man page for strtok(3) and associate freely from there. The main
 **		difference between this and strtok(3) is that the latter modifies the string being
-**		tokenized, whiile this function does not. The <component> buffer is assumed to have
+**		tokenized, while this function does not. The <component> buffer is assumed to have
 **		room for PATH_MAX bytes.
 **		Returns 0 if no more components were found, 1 otherwise.
 ** 1998-08-24 -	Now supports use of environment variable lookups as a "prefix" in a path component,
@@ -449,7 +449,7 @@ const gchar * fut_locate(const gchar *paths, const gchar *name)
 
 	while(fut_path_component(ptr, buf))	/* No, iterate paths. */
 	{
-		stu_strncat(buf, "/",  sizeof buf);
+		stu_strncat(buf, G_DIR_SEPARATOR_S,  sizeof buf);
 		stu_strncat(buf, name, sizeof buf);
 		if(fut_exists(buf))
 			return buf;
@@ -614,7 +614,7 @@ gsize fut_copy_partial(gint in, gint out, gsize chunk_size, gsize length)
 **		complex check.
 ** 1998-09-22 -	Moved this function (and friends) into the fileutil module.
 */
-gboolean fut_can_read(struct stat *stat, uid_t uid, gid_t gid)
+gboolean fut_can_read(const struct stat *stat, uid_t uid, gid_t gid)
 {
 	if(uid == 0)			/* Root rules! */
 		return TRUE;
@@ -642,7 +642,7 @@ gboolean fut_can_read_named(const gchar *name)
 }
 
 /* 1998-09-07 -	Do complex WRITE permission check. */
-gboolean fut_can_write(struct stat *stat, uid_t uid, gid_t gid)
+gboolean fut_can_write(const struct stat *stat, uid_t uid, gid_t gid)
 {
 	if(uid == 0)
 		return TRUE;
@@ -656,7 +656,7 @@ gboolean fut_can_write(struct stat *stat, uid_t uid, gid_t gid)
 }
 
 /* 1998-09-07 -	Do complex EXECUTE permission check. */
-gboolean fut_can_execute(struct stat *stat, uid_t uid, gid_t gid)
+gboolean fut_can_execute(const struct stat *stat, uid_t uid, gid_t gid)
 {
 	if(stat->st_uid == uid)
 		return (stat->st_mode & S_IXUSR) ? TRUE : FALSE;
