@@ -39,10 +39,10 @@ gboolean	fut_size(const gchar *name, gsize *size);
 gboolean	fut_fsize(gint fd, gsize *size);
 void		fut_check_fd(const gchar *label);
 
-gboolean	fut_can_read(struct stat *stat, uid_t uid, gid_t gid);
+gboolean	fut_can_read(const struct stat *stat, uid_t uid, gid_t gid);
 gboolean	fut_can_read_named(const gchar *name);
-gboolean	fut_can_write(struct stat *stat, uid_t uid, gid_t gid);
-gboolean	fut_can_execute(struct stat *stat, uid_t uid, gid_t gid);
+gboolean	fut_can_write(const struct stat *stat, uid_t uid, gid_t gid);
+gboolean	fut_can_execute(const struct stat *stat, uid_t uid, gid_t gid);
 
 gboolean	fut_locate_executable(const gchar *path, const gchar *name);
 
