@@ -15,6 +15,7 @@
 #include "dirpane.h"
 #include "dialog.h"
 #include "userinfo.h"
+#include "file.h"
 #include "fileutil.h"
 #include "xmlutil.h"
 #include "strutil.h"
@@ -33,6 +34,7 @@
 #include "controls.h"
 #include "iconutil.h"
 #include "cmdseq_config.h"
+#include "menus.h"
 
 #include "odlabel.h"
 
@@ -40,16 +42,6 @@
 #include "cfg_module.h"
 #include "cfg_windows.h"
 
-/* No default icon path supplied (expected from use of -D on command line)? */
-#if !defined(PTH_ICN)
-#define	PTH_ICN	"icons:/usr/local/lib/gentoo/icons"
-#endif
-
-/* Also make sure there's a GTK+ RC default path. */
-#if !defined(PTH_GRC)
-#define PTH_GRC	"$HOME/"
-#endif
-
 #include "graphics/icon_iconify.xpm"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -93,15 +85,56 @@ static void evt_main_destroy(GtkWidget *wid, gpointer data)
 }
 
 /* 1998-10-26 -	Initialize some fields in the dp structure. */
-static void init_pane(DirPane *dp, int index)
+static void init_pane(DirPane *dp, gint index)
 {
 	dp->index = index;
-	dp->dir.line = NULL;
+	dp->dir.row = NULL;
 	dp->dir.auxbuf = NULL;
 	dp->hist = dph_dirhistory_new();
 	dp->dir.path[0] = '\0';
 }
 
+static void evt_pane_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer user)
+{
+	MainInfo	*min = user;
+	gint		pos, ww;
+	gdouble		old;
+
+	pos = alloc->width;
+	gdk_window_get_size(((MainInfo *) user)->gui->window->window, &ww, NULL);
+	old = min->cfg.dp_paning.value;
+	switch(min->cfg.dp_paning.mode)
+	{
+		case DPSPLIT_FREE:
+			break;
+		case DPSPLIT_RATIO:
+			min->cfg.dp_paning.value = (gdouble) pos / ww;
+			break;
+		case DPSPLIT_ABS_LEFT:
+			min->cfg.dp_paning.value = pos;
+			break;
+		case DPSPLIT_ABS_RIGHT:
+			min->cfg.dp_paning.value = ww - pos;
+			break;
+	}
+	gtk_signal_handler_block(GTK_OBJECT(min->gui->pane[0].vbox), min->gui->sig_left_sizealloc);
+	if(min->cfg.dp_paning.value != old)
+		cfg_modified_set(min);
+}
+
+/* 2001-08-04 -	Track release of GtkHPaned handle, and react according to current mode. */
+static gboolean evt_paned_buttonrelease(GtkWidget *wid, GdkEventButton *evt, gpointer user)
+{
+	if(evt->window == GTK_PANED(wid)->handle)
+	{
+		MainInfo	*min = user;
+
+		gtk_signal_handler_unblock(GTK_OBJECT(min->gui->pane[0].vbox), min->gui->sig_left_sizealloc);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /* 1998-05-17 -	Build a couple of dir-panes.
 ** 1998-05-18 -	Now also puts the panes in a horizontally paned window, for extra Opusity. ;^)
 ** 1998-08-02 -	Fixed *huge* bug where pane 1 (the right) was built using pane 0's format!!
@@ -115,6 +148,7 @@ static GtkWidget * build_dirpanes(MainInfo *min)
 
 	box = gtk_hbox_new(FALSE, 0);
 	gui->hpane = gtk_hpaned_new();
+	gtk_signal_connect(GTK_OBJECT(gui->hpane), "button_release_event", GTK_SIGNAL_FUNC(evt_paned_buttonrelease), min);
 	init_pane(&gui->pane[0], 0);
 	if((left = dp_build(min, &min->cfg.dp_format[0], &gui->pane[0])) != NULL)
 	{
@@ -145,19 +179,15 @@ static GtkWidget * build_top(GtkWidget **label)
 {
 	GtkWidget	*top, *lab, *hbox;
 
-	if((top = gtk_event_box_new()) != NULL)
-	{
-		hbox = gtk_hbox_new(FALSE, 0);
-		lab = od_label_new("");
-		GTK_WIDGET_SET_FLAGS(GTK_WIDGET(lab), GTK_CAN_FOCUS);
-		gtk_box_pack_start(GTK_BOX(hbox), lab, TRUE, TRUE, 0);
-		gtk_widget_show(lab);
-		gtk_container_add(GTK_CONTAINER(top), hbox);
-		gtk_widget_show(hbox);
-		gtk_widget_show(top);
-		if(label != NULL)
-			*label = lab;
-	}
+	top = gtk_event_box_new();
+	hbox = gtk_hbox_new(FALSE, 0);
+	lab = od_label_new("");
+	GTK_WIDGET_SET_FLAGS(GTK_WIDGET(lab), GTK_CAN_FOCUS);
+	gtk_box_pack_start(GTK_BOX(hbox), lab, TRUE, TRUE, 0);
+	gtk_container_add(GTK_CONTAINER(top), hbox);
+	gtk_widget_show_all(top);
+	if(label != NULL)
+		*label = lab;
 	return top;
 }
 
@@ -166,12 +196,11 @@ static GtkWidget * build_bottom(MainInfo *min)
 {
 	GtkWidget	*hbox, *bbank;
 
-	if((hbox = gtk_hbox_new(FALSE, 0)) != NULL)
-	{
-		bbank = btn_buttonsheet_build(min, &min->cfg.buttons, NULL, FALSE, NULL, min);
-		btn_buttonsheet_built_add_keys(min, GTK_CONTAINER(bbank), NULL);
-		shc_shortcutbank_pack(min, min->cfg.shortcutbank, hbox, bbank);
-	}
+	hbox = gtk_hbox_new(FALSE, 0);
+	bbank = btn_buttonsheet_build(min, &min->cfg.buttons, NULL, FALSE, NULL, min);
+	btn_buttonsheet_built_add_keys(min, GTK_CONTAINER(bbank), NULL);
+	shc_shortcutbank_pack(min, min->cfg.shortcutbank, hbox, bbank);
+
 	return hbox;
 }
 
@@ -183,7 +212,11 @@ void rebuild_middle(MainInfo *min)
 	gtk_container_remove(GTK_CONTAINER(min->gui->hpane), min->gui->pane[0].vbox);
 	gtk_container_remove(GTK_CONTAINER(min->gui->hpane), min->gui->pane[1].vbox);
 	if((left = dp_build(min, &min->cfg.dp_format[0], &min->gui->pane[0])) != NULL)
+	{
+		min->gui->sig_left_sizealloc = gtk_signal_connect(GTK_OBJECT(left), "size_allocate", GTK_SIGNAL_FUNC(evt_pane_sizealloc), min);
+		gtk_signal_handler_block(GTK_OBJECT(left), min->gui->sig_left_sizealloc);
 		gtk_paned_add1(GTK_PANED(min->gui->hpane), left);
+	}	
 	if((right = dp_build(min, &min->cfg.dp_format[1], &min->gui->pane[1])) != NULL)
 		gtk_paned_add2(GTK_PANED(min->gui->hpane), right);
 }
@@ -194,11 +227,9 @@ void rebuild_middle(MainInfo *min)
 void rebuild_bottom(MainInfo *min)
 {
 	gtk_widget_destroy(min->gui->bottom);
-	if((min->gui->bottom = build_bottom(min)) != NULL)
-	{
-		gtk_box_pack_start(GTK_BOX(min->gui->vbox), min->gui->bottom, FALSE, FALSE, 0);
-		gtk_widget_show(min->gui->bottom);
-	}
+	min->gui->bottom = build_bottom(min);
+	gtk_box_pack_start(GTK_BOX(min->gui->vbox), min->gui->bottom, FALSE, FALSE, 0);
+	gtk_widget_show(min->gui->bottom);
 }
 
 /* 1999-03-26 -	Set icon for when gentoo gets iconified. Neato. */
@@ -211,17 +242,46 @@ static void set_icon(GtkWidget *win)
 	{
 		gdk_window_set_icon(win->window, NULL, pmap, bmap);
 		gdk_window_set_icon_name(win->window, "gentoo");
+		gdk_window_set_group(win->window, win->window);
 	}
 }
 
+/* 2001-08-04 -	Update GtkHPaned handle position to maintain the configured split. */
+static void evt_main_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer user)
+{
+	MainInfo	*min = user;
+	gint		pos = -1;
+
+	switch(min->cfg.dp_paning.mode)
+	{
+		case DPSPLIT_FREE:
+			return;
+		case DPSPLIT_RATIO:
+			pos = alloc->width * min->cfg.dp_paning.value;
+			break;
+		case DPSPLIT_ABS_LEFT:
+			pos = min->cfg.dp_paning.value;
+			break;
+		case DPSPLIT_ABS_RIGHT:
+			pos = alloc->width - min->cfg.dp_paning.value;
+			break;
+	}
+	if(pos > 0)
+		gtk_paned_set_position(GTK_PANED(min->gui->hpane), pos);
+}
+
 static GtkWidget * build_gui(MainInfo *min)
 {
+	gchar		title[64];
 	GtkWidget	*top, *panes, *bottom;
 
-	min->gui = g_malloc(sizeof(*min->gui));
+	min->gui = g_malloc(sizeof *min->gui);
+	min->gui->window = NULL;
 	min->gui->window = win_window_open(min->cfg.wininfo, WIN_MAIN);
-	gtk_window_set_title(GTK_WINDOW(min->gui->window), "gentoo v" VERSION);
+	g_snprintf(title, sizeof title, "gentoo v" VERSION "%s", geteuid() == 0 ? " [root]" : "");
+	gtk_window_set_title(GTK_WINDOW(min->gui->window), title);
 	gtk_object_set_user_data(GTK_OBJECT(min->gui->window), (gpointer) min);
+	gtk_signal_connect(GTK_OBJECT(min->gui->window), "size_allocate", GTK_SIGNAL_FUNC(evt_main_sizealloc), min);
 	min->gui->pane[0].main = min;
 	min->gui->pane[0].list = NULL;
 	min->gui->pane[1].main = min;
@@ -230,25 +290,24 @@ static GtkWidget * build_gui(MainInfo *min)
 	min->gui->vbox = gtk_vbox_new(FALSE, 0);
 	min->gui->main_tt = gtk_tooltips_new();
 	min->gui->kbd_ctx = kbd_context_new(min);
+	min->gui->sig_left_sizealloc = 0U;
 	if((top = build_top(&min->gui->top)) != NULL)
 	{
 		if((panes = build_dirpanes(min)) != NULL)
 		{
-			if((bottom = build_bottom(min)) != NULL)
-			{
-				gtk_box_pack_start(GTK_BOX(min->gui->vbox), top,    FALSE, FALSE, 0);
-				gtk_box_pack_start(GTK_BOX(min->gui->vbox), panes,  TRUE,  TRUE,  0);
-				gtk_box_pack_start(GTK_BOX(min->gui->vbox), bottom, FALSE, FALSE, 0);
-				gtk_widget_show(bottom);
-				gtk_widget_show(min->gui->vbox);
-				min->gui->middle = panes;
-				min->gui->bottom = bottom;
-				min->gui->cur_pane = NULL;
-				gtk_tooltips_enable(min->gui->main_tt);
-				kbd_context_attach(min->gui->kbd_ctx, GTK_WINDOW(min->gui->window));
-				ctrl_keys_install(min->cfg.ctrlinfo, min->gui->kbd_ctx);
-				return min->gui->vbox;
-			}
+			bottom = build_bottom(min);
+			gtk_box_pack_start(GTK_BOX(min->gui->vbox), top,    FALSE, FALSE, 0);
+			gtk_box_pack_start(GTK_BOX(min->gui->vbox), panes,  TRUE,  TRUE,  0);
+			gtk_box_pack_start(GTK_BOX(min->gui->vbox), bottom, FALSE, FALSE, 0);
+			gtk_widget_show(bottom);
+			gtk_widget_show(min->gui->vbox);
+			min->gui->middle = panes;
+			min->gui->bottom = bottom;
+			min->gui->cur_pane = NULL;
+			gtk_tooltips_enable(min->gui->main_tt);
+			kbd_context_attach(min->gui->kbd_ctx, GTK_WINDOW(min->gui->window));
+			ctrl_keys_install(min->cfg.ctrlinfo, min->gui->kbd_ctx);
+			return min->gui->vbox;
 			gtk_widget_destroy(panes);
 		}
 		gtk_widget_destroy(top);
@@ -260,8 +319,8 @@ static GtkWidget * build_gui(MainInfo *min)
 /* 1998-08-23 -	Initialize the paths config data. */
 static void init_paths(CfgInfo *cfg)
 {
-	cfg->path.path[PTID_ICON]  = g_string_new(PTH_ICN);
-	cfg->path.path[PTID_GTKRC] = g_string_new(PTH_GRC);
+	cfg->path.path[PTID_ICON]  = g_string_new(PATH_ICN);
+	cfg->path.path[PTID_GTKRC] = g_string_new(PATH_GRC);
 	cfg->path.path[PTID_FSTAB] = g_string_new("/etc/fstab");
 	cfg->path.path[PTID_MTAB]  = g_string_new("/proc/mounts");
 
@@ -275,6 +334,7 @@ static void init_paths(CfgInfo *cfg)
 /* 1998-11-29 -	Load the GTK+ RC file, allowing users to configure gentoo's looks. The
 **		file is always named ".gentoogtkrc" (too long, I know) but you can put
 **		it anywhere as long as you given gentoo the path (in the config).
+** 2001-08-12 -	The dot is now optional, but is given priority if found.
 */
 static void load_gtk_rc(MainInfo *min)
 {
@@ -282,6 +342,8 @@ static void load_gtk_rc(MainInfo *min)
 
 	if((name = fut_locate(min->cfg.path.path[PTID_GTKRC]->str, ".gentoogtkrc")) != NULL)
 		gtk_rc_parse(name);
+	else if((name = fut_locate(min->cfg.path.path[PTID_GTKRC]->str, "gentoogtkrc")) != NULL)
+		gtk_rc_parse(name);
 }
 
 /* 1999-04-04 -	Initialize default (er, and non-configurable) command options. I'll
@@ -302,7 +364,14 @@ static void evt_key_press(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 {
 	MainInfo	*min = user;
 
-	if((evt->keyval == GDK_s))
+	if(evt->keyval == GDK_v)
+	{
+		GtkAdjustment	*adj;
+
+		if((adj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(min->gui->cur_pane->scwin))) != NULL)
+			printf("Adj: lower=%g upper=%g value=%g\n", adj->lower, adj->upper, adj->value);
+	}
+	else if((evt->keyval == GDK_s))
 		dp_focus(min->gui->cur_pane, 3);
 	else if(evt->keyval == GDK_x)
 		dp_focus(min->gui->cur_pane, 8);
@@ -318,6 +387,13 @@ static void evt_key_press(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 		printf("You answered %d\n", ret);
 		dlg_dialog_sync_destroy(dlg);
 	}
+	else if(evt->keyval == GDK_1)
+	{
+		min->cfg.dp_paning.mode++;
+		if(min->cfg.dp_paning.mode > DPSPLIT_ABS_RIGHT)
+			min->cfg.dp_paning.mode = DPSPLIT_FREE;
+		printf("Pane split mode: %d\n", min->cfg.dp_paning.mode);
+	}
 }
 #endif
 
@@ -328,7 +404,7 @@ int main(int argc, char *argv[])
 	GtkWidget	*box;
 	static MainInfo	min;
 
-#if defined(ENABLE_NLS)
+#if defined ENABLE_NLS
 	setlocale(LC_ALL, "");
 	bindtextdomain(GENTOO_PACKAGE, GENTOO_LOCALEDIR);
 	textdomain(GENTOO_PACKAGE);
@@ -348,18 +424,21 @@ int main(int argc, char *argv[])
 
 	dpf_initialize();
 	sze_initialize();
+	mnu_initialize();
 
 	min.cfg.flags = 0;
 	dpf_init_defaults(&min.cfg);
 	csq_init_commands(&min);
 	mnt_init_defaults(&min.cfg);
 	min.cfg.shortcutbank = shc_shortcutbank_new_default();
-	btn_buttoninfo_default(&min, &min.cfg.buttons);
+	min.cfg.menus = mnu_menuinfo_new_default(&min);
+	btn_buttoninfo_new_default(&min, &min.cfg.buttons);
 	init_paths(&min.cfg);
 	min.cfg.style = stl_styleinfo_default();
 	typ_init(&min.cfg);
 	min.cfg.wininfo	 = win_wininfo_new_default(&min);
 	min.cfg.ctrlinfo = ctrl_new_default(&min);
+	min.cfg.errors.dialog = FALSE;
 	min.cfg.dir_filter = dir_filter;
 	chd_initialize(&min);
 	min.que = que_initialize();
@@ -370,18 +449,16 @@ int main(int argc, char *argv[])
 	min.ico = ico_initialize(&min);
 
 	if(!usr_init())
-	{
-		fprintf(stderr, "%s: Couldn't initialize userinfo module\n", g_get_prgname());
-		exit(EXIT_FAILURE);
-	}
+		g_error("Couldn't initialize userinfo module");
 	if((min.cfg.mount.mode != MNT_NEVER) && (!mnt_init(&min)))
-		fprintf(stderr, "%s: Couldn't initialize mount data - automount won't work\n", g_get_prgname());
+		g_warning("Couldn't initialize mount data - automount won't work");
 
 	if(!(arg_flags & OPTF_NO_GTKRC))
 		load_gtk_rc(&min);
 
 	if((box = build_gui(&min)) != NULL)
 	{
+		dlg_group_set(min.gui->window->window);
 		min.gui->win_del_evt = gtk_signal_connect(GTK_OBJECT(min.gui->window), "delete_event", GTK_SIGNAL_FUNC(evt_main_delete), &min);
 		gtk_signal_connect(GTK_OBJECT(min.gui->window), "destroy", GTK_SIGNAL_FUNC(evt_main_destroy), NULL);
 #if 0
@@ -401,6 +478,10 @@ int main(int argc, char *argv[])
 		set_icon(min.gui->window);
 		win_window_show(min.gui->window);
 
+		min.gui->sig_left_sizealloc = gtk_signal_connect(GTK_OBJECT(min.gui->pane[0].vbox), "size_allocate",
+								GTK_SIGNAL_FUNC(evt_pane_sizealloc), &min);
+		gtk_signal_handler_block(GTK_OBJECT(min.gui->pane[0].vbox), min.gui->sig_left_sizealloc);
+
 		csq_execute(&min, "ActivateRight");
 		csq_execute_format(&min, "DirEnter 'dir=%s'", dir[1]);
 		csq_execute(&min, "ActivateLeft");
@@ -415,5 +496,5 @@ int main(int argc, char *argv[])
 	}
 	mnt_shutdown(&min);
 
-	return 0;
+	return EXIT_SUCCESS;
 }
