@@ -11,14 +11,16 @@
 ** system-dependant things which need to go before any system headers are included.
 */
 
-#if !defined(__alpha)		/* I've heard this helps on Alpha systems... */
+#include "config.h"
+
+#if !defined __alpha && !defined __NetBSD__
 #define __EXTENSIONS__
 #define _POSIX_C_SOURCE	3	/* This is for Solaris. */
 #define	POSIX_C_SOURCE	3
 
 #endif				/* !__alpha */
 
-#if defined(__osf__) && defined(__alpha__)		/* On Tru64, this should bring in mknod(). */
+#if defined __osf__ && defined __alpha__		/* On Tru64, this should bring in mknod(). */
 #define	_XOPEN_SOURCE_EXTENDED
 #define	_OSF_SOURCE					/* For MAXNAMLEN on Tru64. */
 #endif
@@ -37,10 +39,10 @@
 #include <unistd.h>
 #include <regex.h>
 
-#if defined(__linux)
+#if defined __linux
 #include <linux/limits.h>
 #include <sys/vfs.h>
-#elif defined(__OpenBSD__) || defined(__FreeBSD__)
+#elif defined __OpenBSD__ || defined __FreeBSD__ || defined __NetBSD__
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
@@ -50,37 +52,29 @@
 #define	GTK_DISABLE_COMPAT_H		/* No GTK+ 1.0.6-compatibility required. */
 
 #include <gtk/gtk.h>
-#include <glib.h>
 
 /* Not all systems' <mman.h> seem to define this. */
-#if !defined(MAP_FAILED)
+#if !defined MAP_FAILED
 #define	MAP_FAILED	((void *) -1)
 #endif
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* The overall gentoo release version. Standard major.minor.micro format. The minor
-** component will be odd for development versions.
-*/
-#define	VERSION	"0.11.15"
-
 #define	RCNAME	".gentoorc"
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* For now, internationalization is disabled. Before I enable it, I need
-** real autoconfig/automake/autoeverything support, otherwise the build
-** process will become too complicated (um, perhaps it already is) for me
-** to have a chance of getting it work on more than one architecture.
-** Unfortunately, I can't seem quite able to get my head around autoconfig
-** yet. Help is very much welcome (that means you, Lasse :^).
+/* Internationalization is still disabled. I haven't gotten around to
+** integrating it with the still new autoconf build process. Help is
+** welcome.
 */
 #undef	ENABLE_NLS
 
-#if defined(ENABLE_NLS)
-/* These two are used to mark translatable strings in the source code. That is
-** a rather big task, and I haven't even started yet. Having the macros defined
-** at least makes it possible to start. I18N, here we come! ;^) Soon.
+#if defined ENABLE_NLS
+/* These two are used to mark translatable strings in the source code.
+** _() is used in contexts where C allows a function call, N_() where
+** it does not. Strings marked with N_() still need to be passed to _()
+** before being shown to the user.
 */
 #include <libintl.h>
 #define	_(str)	gettext(str)
@@ -109,6 +103,7 @@ typedef struct CmdSeq		CmdSeq;
 #include "styles.h"
 #include "dirhistory.h"
 #include "window.h"
+#include "menus.h"
 
 #define	KEY_NAME_SIZE	(32)
 
@@ -232,6 +227,14 @@ typedef struct {
 	GdkColor	color[DPCOL_NUM];
 } DPColors;
 
+typedef enum { DPSPLIT_FREE = 0, DPSPLIT_RATIO, DPSPLIT_ABS_LEFT, DPSPLIT_ABS_RIGHT } DpSplit;
+
+/* Allow user to control how gentoo should allocate window space between the panes. */
+typedef struct {
+	DpSplit	mode;
+	gdouble	value;		/* Parameter interpreted depending on mode. */
+} DPPaning;
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* General command row flags. */
@@ -304,7 +307,7 @@ typedef struct {
 	GList	*sheets;			/* List of button sheets. */
 } ButtonInfo;
 
-typedef struct {
+/*typedef struct {
 	gchar	*text;
 	gchar	*command;
 } MenuItem;
@@ -312,10 +315,11 @@ typedef struct {
 typedef struct {
 	MenuItem	*menuitem;
 } MenuRoot;
+*/
 
 typedef struct {			/* Options for overwrite-confirmation dialog module. */
 	gint	show_info : 1;			/* Show info (sizes & dates) for conflicting files? */
-	char	datefmt[DP_DATEFMT_SIZE];	/* How to format dates? */
+	gchar	datefmt[DP_DATEFMT_SIZE];	/* How to format dates? */
 } OptOverwrite;
 
 typedef enum { HIDE_NONE, HIDE_DOT, HIDE_REGEXP } HMode;
@@ -352,6 +356,10 @@ typedef struct {			/* Configuration info for automounting. */
 	gchar	cmd_umount[MAXNAMLEN];		/* This command is used for unmounting. ["/bin/umount"] */
 } MountInfo;
 
+typedef struct {
+	gboolean	dialog;			/* Use dialog for errors? */
+} ErrInfo;
+
 #define	CFLG_CHANGED	(1<<0)		/* Config has changed. Set on "OK", cleared by cfg_save_all(). */
 
 typedef struct {			/* Holds all configuration info. */
@@ -360,14 +368,17 @@ typedef struct {			/* Holds all configuration info. */
 	StyleInfo	*style;			/* Opaque style container. */
 	DPFormat	dp_format[2];
 	DPColors	dp_colors;		/* Global color information used to render dirpanes. */
+	DPPaning	dp_paning;		/* Controls how the paned view acts. */
 	OptOverwrite	opt_overwrite;
 	ShortcutBank	*shortcutbank;
+	MenuInfo	*menus;
 	ButtonInfo	buttons;
 	CmdInfo		commands;
 	PathInfo	path;
 	MountInfo	mount;
 	WinInfo		*wininfo;
 	CtrlInfo	*ctrlinfo;
+	ErrInfo		errors;
 	gboolean	(*dir_filter)(const gchar *name);
 } CfgInfo;
 
@@ -392,7 +403,7 @@ struct MainInfo {				/* gentoo's single most central data structure. */
 #define	DP_ROW_FLAGS_CLR(r,f)	(DP_ROW_FLAGS(r) &= ~(f))
 #define	DP_ROW_FLAGS_CHK(r,f)	((DP_ROW_FLAGS(r) & (f)) == (f))
 #define	DP_ROW_TYPE(r)		((r)->dr_type)
-#define	DP_ROW_INDEX(p,r)	((r) - (p)->dir.line)
+#define	DP_ROW_INDEX(p,r)	((r) - (p)->dir.row)
 
 #define	DP_ROW_SET_STAT(r,s)	(((r)->dr_stat) = (s))
 #define	DP_ROW_GET_STAT(r)	((r)->dr_stat)
@@ -431,7 +442,7 @@ typedef struct {
 
 typedef struct {			/* Some trivial file system information. Updated on rescan. */
 	gboolean	valid;			/* Set if the structure's contents are valid. */
-#if defined(__linux) || defined(__OpenBSD__) || defined(__FreeBSD__)
+#if defined __linux || defined __OpenBSD__ || defined __FreeBSD__ || defined __NetBSD__
 	struct statfs	stat;			/* Holds information about filesystem. */
 #else
 	struct statvfs	stat;
@@ -440,10 +451,10 @@ typedef struct {			/* Some trivial file system information. Updated on rescan. *
 
 typedef struct {
 	gchar		path[PATH_MAX];		/* Contents apply to this path. */
-	guint		num_lines;		/* Number of valid lines. */
+	guint		num_rows;		/* Number of valid lines. */
 	guint		tot_dirs, tot_files;	/* Total number of entries in directory. */
 	guint64		tot_bytes, tot_blocks;	/* Sum of all sizes (in bytes & blocks). */
-	DirRow		*line;			/* A bunch of lines. */
+	DirRow		*row;			/* A bunch of rows. */
 	gchar		*auxbuf;		/* This holds auxillary info (names, link names, and link stats). */
 	SelInfo		sel;
 	FsInfo		fs;
@@ -486,6 +497,7 @@ struct GuiInfo {
 	GtkWidget	*bottom;		/* Bottom part of GUI. */
 	DirPane		pane[2];
 	DirPane		*cur_pane;
+	guint		sig_left_sizealloc;	/* Handler ID for "size_allocate" signal on left pane. */
 
 	gboolean	evt_button_valid;
 	GdkEventButton	evt_button;
