@@ -43,7 +43,7 @@ struct IconInfo {
 };
 
 typedef struct {
-	gchar		name[PATH_MAX];			/* This is real big. */
+	gchar		name[PATH_MAX];		/* This is real big. */
 	GdkPixmap	*pixmap;
 	GdkBitmap	*mask;
 } IconGfx;
@@ -156,7 +156,7 @@ static IconGfx * load(IconInfo *ico, const gchar *name)
 }
 
 /* 1998-08-15 -	Internal icon retrieval function. Does a lookup in the hash table, loads
-**		from disk if not found. The <win> parameter is annoying but required.
+**		from disk if not found.
 */
 static GdkPixmap * get_or_load(IconInfo *ico, const gchar *name, GdkBitmap **mask)
 {
@@ -206,13 +206,17 @@ GdkPixmap * ico_icon_get(MainInfo *min, const gchar *name, GdkBitmap **mask)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-11-21 -	Kill given icon. This is a g_hash_table_foreach_remove() callback. */
+/* 1999-11-21 -	Kill given icon. This is a g_hash_table_foreach_remove() callback.
+** 2001-01-01 -	Happy new year! :) Um, now frees the memory, too...
+*/
 static gboolean kill_icon(gpointer key, gpointer value, gpointer user)
 {
 	IconGfx	*icon = (IconGfx *) value;
 
 	gdk_pixmap_unref(icon->pixmap);
 	gdk_bitmap_unref(icon->mask);
+	g_free(icon);
+
 	return TRUE;			/* Tells glib to actually remove hash entry. */
 }
 
