@@ -2,7 +2,7 @@
 ** 1998-08-15 -	Header for the icon utility module.
 */
 
-#if !defined(ICONUTIL_H)
+#if !defined ICONUTIL_H
 #define	ICONUTIL_H
 
 typedef struct IconInfo	IconInfo;
