@@ -2,7 +2,7 @@
 ** 1998-09-20 -	Header for the very small and simple pseudo-queue module.
 */
 
-#if !defined(QUEUE_H)
+#if !defined QUEUE_H
 #define	QUEUE_H
 
 typedef struct QueueInfo	QueueInfo;
