@@ -567,11 +567,11 @@ void stl_styleinfo_save(MainInfo *min, StyleInfo *si, FILE *out, const gchar *ta
 **		integers, into the newer named style. Add the property to the style pointed
 **		to by <user>.
 */
-static void old_load_property(XmlNode *node, gpointer user)
+static void old_load_property(const XmlNode *node, gpointer user)
 {
 	gint		type;
 	gboolean	ok = FALSE;
-	gchar		*name = NULL, *text = NULL;
+	const gchar	*name = NULL, *text = NULL;
 	GdkColor	col;
 	StlPType	newtype = SPT_COLOR;
 	Style		*stl = user;
@@ -622,7 +622,7 @@ static void old_load_property(XmlNode *node, gpointer user)
 				newtype = SPT_ACTION;
 			break;
 		default:
-			fprintf(stderr, "STYLES: Ignoring unknown legacy property type %d in style '%s'\n", type, stl->name);
+			g_warning("STYLES: Ignoring unknown legacy property type %d in style '%s'\n", type, stl->name);
 	}
 	if(ok)
 	{
@@ -642,15 +642,15 @@ static void old_load_property(XmlNode *node, gpointer user)
 }
 
 /* 1999-05-27 -	Load modern-style property (has textual identifier). Pretty simple stuff. */
-static void load_property(XmlNode *data, gpointer user)
+static void load_property(const XmlNode *data, gpointer user)
 {
-	Style	*stl = user;
-	gchar	*name;
+	Style		*stl = user;
+	const gchar	*name;
 
 	if(xml_get_text(data, "name", &name))
 	{
 		GdkColor	color;
-		gchar		*text;
+		const gchar	*text;
 
 		if(xml_get_color(data, "color", &color))
 			stl_style_property_set_color(stl, name, &color);
@@ -659,7 +659,7 @@ static void load_property(XmlNode *data, gpointer user)
 		else if(xml_get_text(data, "action", &text))
 			stl_style_property_set_action(stl, name, csq_cmdseq_map_name(text, stl_style_get_name(stl)));
 		else
-			fprintf(stderr, "STYLES: Unknown value type for property '%s' (style '%s')\n", name, stl->name);
+			g_warning("STYLES: Unknown value type for property '%s' (style '%s')\n", name, stl->name);
 	}
 }
 
@@ -667,9 +667,9 @@ static void load_property(XmlNode *data, gpointer user)
 **		given style, and store them in the style. This is where the backwards-
 **		compatibility really gets going.
 */
-static void load_properties(XmlNode *node, Style *stl)
+static void load_properties(const XmlNode *node, Style *stl)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = xml_tree_search(node, "Property")) != NULL)
 	{
@@ -683,12 +683,12 @@ static void load_properties(XmlNode *node, Style *stl)
 /* 1999-05-20 -	A xml_node_visit_children() callback to load in a style. Deals with the
 **		annoying complexities of backwards compatibility. :(
 */
-static void load_style(XmlNode *node, gpointer user)
+static void load_style(const XmlNode *node, gpointer user)
 {
 	StyleInfo	*si = user;
 	Style		*stl, *parent = NULL;
-	gchar		*name = "new style", *pname;
-	XmlNode		*prop;
+	const gchar	*name = "new style", *pname;
+	const XmlNode	*prop;
 	gboolean	btmp = FALSE;
 
 	xml_get_text(node, "name", &name);
@@ -696,10 +696,8 @@ static void load_style(XmlNode *node, gpointer user)
 	
 	if(xml_get_boolean(node, "expand", &btmp))
 		stl_style_set_expand(stl, btmp);
-
 	if((prop = xml_tree_search(node, "Properties")) != NULL)
 		load_properties(prop, stl);
-
 	if(xml_get_text(node, "parent", &pname))
 		parent = stl_styleinfo_style_find(si, pname);
 	stl_styleinfo_style_add(si, parent, stl);
@@ -710,7 +708,7 @@ static void load_style(XmlNode *node, gpointer user)
 **		have been used before calling this function, to find <node>. It is assumed
 **		that the given node contains a bunch of children, each of which defines a style.
 */
-StyleInfo * stl_styleinfo_load(XmlNode *node)
+StyleInfo * stl_styleinfo_load(const XmlNode *node)
 {
 	StyleInfo	*si;
 
@@ -1264,6 +1262,18 @@ GList * stl_style_property_get_actions(Style *stl)
 	return list;
 }
 
+gboolean stl_style_property_has_action(const Style *stl, const gchar *action)
+{
+	StlProp	*p;
+
+	if((p = g_hash_table_lookup(stl->properties, action)) != NULL)
+	{
+		if(p->value->type == SPT_ACTION)
+			return TRUE;
+	}
+	return FALSE;
+}
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-27 -	Another g_hash_table_foreach() callback. This one checks for overrides. */
