@@ -189,7 +189,7 @@ int txv_load_text(GtkWidget *wid, const char *name, gboolean use_mmap, gsize buf
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-12-18 -	Build "groups" of actual hex data, from <data> and <bytes> bytes on. */
-static void build_hex_group(char *data, char *group, gsize bytes)
+static void build_hex_group(const guchar *data, gchar *group, gsize bytes)
 {
 	gchar	*hex = "0123456789ABCDEF", *ptr = group;
 	guint8	here;
@@ -206,12 +206,12 @@ static void build_hex_group(char *data, char *group, gsize bytes)
 }
 
 /* 1998-12-18 -	Build text representation of stuff found at <data>, <bytes> bytes worth. */
-static void build_hex_text(char *data, char *text, gsize bytes)
+static void build_hex_text(const guchar *data, gchar *text, gsize bytes)
 {
 	gsize	i;
 
 	for(i = 0; i < bytes; i++, data++)
-		*text++ = isprint((unsigned char) *data) ? *data : HEX_UNPRINTABLE;
+		*text++ = isprint((int) *data) ? *data : HEX_UNPRINTABLE;
 }
 
 /* 1998-12-18 -	Add contents of file <name> into GtkText widget <wid>, as a hex dump.
@@ -225,11 +225,11 @@ static void build_hex_text(char *data, char *text, gsize bytes)
 **		Now we do plenty of small read()s instead, which I'm sure is slower, but at
 **		least doesn't waste memory.
 */
-int txv_load_text_hex(GtkWidget *win, const char *name)
+int txv_load_text_hex(GtkWidget *win, const gchar *name)
 {
 	gchar		line[8 + 1 + (HEX_ROW_SIZE / 4) * 9 + 1 + HEX_ROW_SIZE + 1 + 1],
-			group[9 * (HEX_ROW_SIZE / 4) + 1], text[HEX_ROW_SIZE + 1],
-			buf[HEX_ROW_SIZE];
+			group[9 * (HEX_ROW_SIZE / 4) + 1], text[HEX_ROW_SIZE + 1];
+	guchar		buf[HEX_ROW_SIZE];
 	gint		fd;
 	gsize		chunk, offset = 0;
 	TxvInfo		*txi;
@@ -363,11 +363,10 @@ static void evt_goto_clicked(GtkWidget *wid, gpointer user)
 	goto_dialog.vbox  = gtk_vbox_new(FALSE, 0);
 	goto_dialog.label = gtk_label_new(_("Enter Line Number or Percentage:"));
 	gtk_box_pack_start(GTK_BOX(goto_dialog.vbox), goto_dialog.label, FALSE, FALSE, 0);
-	gtk_widget_show(goto_dialog.label);
 	goto_dialog.entry = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(goto_dialog.vbox), goto_dialog.entry, FALSE, FALSE, 0);
-	gtk_widget_show(goto_dialog.entry);
 
+	gtk_widget_show_all(goto_dialog.vbox);
 	goto_dialog.dlg = dlg_dialog_sync_new(goto_dialog.vbox, _("Goto"), _("OK|Cancel"));
 	gtk_widget_grab_focus(goto_dialog.entry);
 	if((dlg_dialog_sync_wait(goto_dialog.dlg) == DLG_POSITIVE) &&
@@ -427,7 +426,7 @@ static gint evt_close_clicked(GtkWidget *wid, gpointer data)
 **		accomplish this that eliminates this problem: use a insert/delete pair.
 **		However, that causes the widget to *scroll* to the required position. Yawn.
 */
-static void show_text(TxvInfo *txi, int pos)
+static void show_text(TxvInfo *txi, gint pos)
 {
 	GtkAdjustment	*adj;
 	GtkStyle	*stl;
@@ -501,24 +500,20 @@ static void evt_search_clicked(GtkWidget *wid, gpointer data)
 	srch_dialog.vbox  = gtk_vbox_new(FALSE, 0);
 	srch_dialog.label = gtk_label_new(_("Enter Text to Search For (RE)"));
 	gtk_box_pack_start(GTK_BOX(srch_dialog.vbox), srch_dialog.label, FALSE, FALSE, 0);
-	gtk_widget_show(srch_dialog.label);
 	srch_dialog.entry = gtk_entry_new_with_max_length(SEARCH_RE_SIZE - 1);
 	gtk_entry_set_text(GTK_ENTRY(srch_dialog.entry), last_re);
 	gtk_editable_select_region(GTK_EDITABLE(srch_dialog.entry), 0, -1);
 	gtk_box_pack_start(GTK_BOX(srch_dialog.vbox), srch_dialog.entry, FALSE, FALSE, 0);
-	gtk_widget_show(srch_dialog.entry);
 	srch_dialog.hbox  = gtk_hbox_new(FALSE, 0);
 	srch_dialog.fnocase = gtk_check_button_new_with_label(_("Ignore Case?"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(srch_dialog.fnocase), last_fnocase);
 	gtk_box_pack_start(GTK_BOX(srch_dialog.hbox), srch_dialog.fnocase, TRUE, TRUE, 0);
-	gtk_widget_show(srch_dialog.fnocase);
 	srch_dialog.fnolf = gtk_check_button_new_with_label(_("Don't Span Newlines?"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(srch_dialog.fnolf), last_fnolf);
 	gtk_box_pack_start(GTK_BOX(srch_dialog.hbox), srch_dialog.fnolf, TRUE, TRUE, 0);
-	gtk_widget_show(srch_dialog.fnolf);
 	gtk_box_pack_start(GTK_BOX(srch_dialog.vbox), srch_dialog.hbox, FALSE, FALSE, 0);
-	gtk_widget_show(srch_dialog.hbox);
 
+	gtk_widget_show_all(srch_dialog.vbox);
 	srch_dialog.dlg = dlg_dialog_sync_new(srch_dialog.vbox, _("Search"), _("OK|Cancel"));
 	gtk_widget_grab_focus(srch_dialog.entry);
 	if(dlg_dialog_sync_wait(srch_dialog.dlg) == DLG_POSITIVE)
@@ -576,12 +571,9 @@ GtkWidget * txv_open(MainInfo *min, const gchar *label)
 	txi->keypress_handler = 0;
 
 	txi->win = win_window_open(min->cfg.wininfo, WIN_TEXTVIEW);
-/*	txi->win = gtk_window_new(GTK_WINDOW_DIALOG);*/
-/*	gtk_window_set_default_size(GTK_WINDOW(txi->win), 640, 480);*/
 	gtk_object_set_user_data(GTK_OBJECT(txi->win), (gpointer) txi);
 	gtk_signal_connect(GTK_OBJECT(txi->win), "delete_event", GTK_SIGNAL_FUNC(evt_delete), (gpointer) txi);
 	txv_connect_keypress(txi->win, NULL, NULL);
-/*	txv_connect_keypress(txi->win, GTK_SIGNAL_FUNC(evt_keypress), txi->win);*/
 
 	vbox = gtk_vbox_new(FALSE, 0);
 
@@ -596,10 +588,8 @@ GtkWidget * txv_open(MainInfo *min, const gchar *label)
 	gtk_signal_connect(GTK_OBJECT(gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(txi->scwin))),
 				"value_changed", GTK_SIGNAL_FUNC(evt_pos_changed), (gpointer) txi);
 	gtk_container_add(GTK_CONTAINER(txi->scwin), txi->text);
-	gtk_widget_show(txi->text);
 
 	gtk_box_pack_start(GTK_BOX(vbox), txi->scwin, TRUE, TRUE, 0);
-	gtk_widget_show(txi->scwin);
 
 	txi->bhbox = gtk_hbox_new(FALSE, 0);
 	algn = gtk_alignment_new(0.01, 0.5, 0, 0);
@@ -608,59 +598,46 @@ GtkWidget * txv_open(MainInfo *min, const gchar *label)
 	else
 		txi->blabel = gtk_label_new("");
 	gtk_container_add(GTK_CONTAINER(algn), txi->blabel);
-	gtk_widget_show(txi->blabel);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), algn, TRUE, TRUE, 10);
-	gtk_widget_show(algn);
 
 	algn = gtk_alignment_new(0.99, 0.5, 0, 0);
 	txi->bplabel = gtk_label_new("");
 	gtk_container_add(GTK_CONTAINER(algn), txi->bplabel);
-	gtk_widget_show(txi->bplabel);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), algn, TRUE, TRUE, 0);
-	gtk_widget_show(algn);
 
 	btn = gui_arrow_button_new(GTK_ARROW_UP);
 	gtk_object_set_user_data(GTK_OBJECT(btn), (gpointer) MVE_UP);
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_move_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 	btn = gui_arrow_button_new(GTK_ARROW_DOWN);
 	gtk_object_set_user_data(GTK_OBJECT(btn), (gpointer) MVE_DOWN);
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_move_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 	btn = gtk_button_new_with_label(_("Top"));
 	gtk_object_set_user_data(GTK_OBJECT(btn), (gpointer) MVE_TOP);
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_move_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 	btn = gtk_button_new_with_label(_("Bottom"));
 	gtk_object_set_user_data(GTK_OBJECT(btn), (gpointer) MVE_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_move_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 
 	bhbox = gtk_hbox_new(FALSE, 0);
 	btn = gtk_button_new_with_label(_("Goto..."));
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_goto_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 	btn = gtk_button_new_with_label(_("Search..."));
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_search_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(bhbox), btn, FALSE, FALSE, 0);
-	gtk_widget_show(btn);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), bhbox, FALSE, FALSE, 5);
-	gtk_widget_show(bhbox);
 
 	btn = gtk_button_new_with_label(_("Close"));
 	gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(evt_close_clicked), (gpointer) txi);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), btn, FALSE, TRUE, 0);
-	gtk_widget_show(btn);
 	gtk_widget_set_sensitive(txi->bhbox, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox), txi->bhbox, FALSE, FALSE, 0);
-	gtk_widget_show(txi->bhbox);
 	gtk_container_add(GTK_CONTAINER(txi->win), vbox);
-	gtk_widget_show(vbox);
+	gtk_widget_show_all(vbox);
 
 	gtk_widget_grab_focus(txi->text);
 	return txi->win;
@@ -700,7 +677,7 @@ guint txv_connect_keypress(GtkWidget *wid, GtkSignalFunc func, gpointer user)
 /* 1999-01-05 -	Set the label. This is kind of redundant, but true to the original Opus look. :)
 ** 1999-03-02 -	New interface.
 */
-void txv_set_label(GtkWidget *wid, const char *text)
+void txv_set_label(GtkWidget *wid, const gchar *text)
 {
 	TxvInfo	*txi;
 
