@@ -4,7 +4,7 @@
 **		GTK+ widget. Makes life easier for the cmdgrab module.
 */
 
-#if !defined(TEXTVIEW_H)
+#if !defined TEXTVIEW_H
 #define TEXTVIEW_H
 
 /* Open and return a pointer to a text viewing window. The only thing the caller
@@ -21,14 +21,14 @@ void		txv_show(GtkWidget *textviewer);
 */
 guint		txv_connect_keypress(GtkWidget *wid, GtkSignalFunc func, gpointer user);
 
-void		txv_set_label(GtkWidget *wid, const char *text);
+void		txv_set_label(GtkWidget *wid, const gchar *text);
 
 void		txv_freeze(GtkWidget *wid);
 void		txv_thaw(GtkWidget *wid);
 
-void		txv_put_text(GtkWidget *wid, const char *text, int length);
-int		txv_load_text(GtkWidget *wid, const char *name, gboolean use_mmap, gsize buf_size);
-int		txv_load_text_hex(GtkWidget *wid, const char *name);
+void		txv_put_text(GtkWidget *wid, const gchar *text, gint length);
+int		txv_load_text(GtkWidget *wid, const gchar *name, gboolean use_mmap, gsize buf_size);
+int		txv_load_text_hex(GtkWidget *wid, const gchar *name);
 
 void		txv_enable(GtkWidget *wid);
 
