@@ -38,10 +38,6 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* These improve readability of file I/O calls when dealing with 'file'. */
-#define	FD_INPUT	(0)
-#define	FD_OUTPUT	(1)
-
 /* This list is used between typ_identify_begin() and typ_identify_end() to hold directory
 ** lines that seem to need to be shown to the external 'file' command.
 */
@@ -328,7 +324,7 @@ void typ_identify(MainInfo *min, DirRow *row)
 **		<fout>. Only types that include a 'file'-matching RE are checked, of course.
 **		Returns the matching type if any, or NULL if there's no match.
 */
-static FType * match_file(GList *list, DirRow *row, char *fout)
+static FType * match_file(GList *list, DirRow *row, const gchar *fout)
 {
 	FType	*type;
 
@@ -337,7 +333,6 @@ static FType * match_file(GList *list, DirRow *row, char *fout)
 		if(check_type(type, row, fout))
 			return type;
 	}
-
 	return NULL;
 }
 
@@ -367,27 +362,27 @@ void typ_identify_end(MainInfo *min, const gchar *path)
 		switch((file_pid = fork()))
 		{
 			case 0:
-				assert(close(FD_INPUT) == 0);			/* Kill stdin. */
-				assert(dup(fd[FD_INPUT]) == FD_INPUT);		/* Replace with pipe from main. */
-				assert(close(fd[FD_INPUT]) == 0);		/* Close the pipe. */
-				assert(close(FD_OUTPUT) == 0);			/* Kill stdout. */
-				assert(open(temp_name, O_CREAT|O_RDWR, S_IRWXU) == FD_OUTPUT);
-				assert(close(fd[FD_OUTPUT]) == 0);		/* Close unused pipe. */
-				assert(chdir(path) == 0);			/* Change to the path in question. */
+				assert(close(STDIN_FILENO) == 0);			/* Kill stdin. */
+				assert(dup(fd[STDIN_FILENO]) == STDIN_FILENO);		/* Replace with pipe from main. */
+				assert(close(fd[STDIN_FILENO]) == 0);			/* Close the pipe. */
+				assert(close(STDOUT_FILENO) == 0);			/* Kill stdout. */
+				assert(open(temp_name, O_CREAT|O_RDWR, S_IRWXU) == STDOUT_FILENO);
+				assert(close(fd[STDOUT_FILENO]) == 0);			/* Close unused pipe. */
+				assert(chdir(path) == 0);				/* Change to the path in question. */
 				execlp("file", "file", "-f", "-", NULL);
 				exit(EXIT_FAILURE);
 			case -1:
 				fprintf(stderr, "fork() failed! Damn!\n");
 				exit(EXIT_FAILURE);
 		}
-		assert(close(fd[FD_INPUT]) == 0);		/* Close input part of pipe (used by child). */
+		assert(close(fd[STDIN_FILENO]) == 0);		/* Close input part of pipe (used by child). */
 		for(here = file_list; here != NULL; here = g_list_next(here))
 		{
 			len = g_snprintf(buf, sizeof buf, "%s\n", DP_SEL_NAME(here));
-			write(fd[FD_OUTPUT], buf, len);
+			write(fd[STDOUT_FILENO], buf, len);
 		}
 
-		close(fd[FD_OUTPUT]);
+		close(fd[STDOUT_FILENO]);
 		waitpid(file_pid, &status, 0);
 
 		if(WIFEXITED(status))
@@ -398,7 +393,7 @@ void typ_identify_end(MainInfo *min, const gchar *path)
 				{
 					if((fout = strchr(line, ':')) == NULL)
 						continue;
-					for(fout++; isspace((unsigned char) *fout); fout++)
+					for(fout++; isspace((int) *fout); fout++)
 						;
 					if((type = match_file(min->cfg.type, DP_SEL_ROW(here), fout)) != NULL)
 						DP_SEL_TYPE(here) = type;
@@ -424,7 +419,7 @@ void typ_identify_end(MainInfo *min, const gchar *path)
 */
 void typ_init(CfgInfo *cfg)
 {
-	FType		*type;
+	FType	*type;
 
 	cfg->type = NULL;
 	if((type = typ_type_new(cfg, _("Unknown"), 0, 0, NULL, NULL, NULL)) != NULL)
