@@ -232,8 +232,9 @@ static GtkWidget * subframe_build(const WinInfo *wi, WinDef *win, gint type, gbo
 		gtk_object_set_data(GTK_OBJECT(grab), "spin1", spin1);
 		gtk_object_set_data(GTK_OBJECT(grab), "spin2", spin2);
 		gtk_object_set_data(GTK_OBJECT(grab), "modified", modified);
-		gtk_signal_connect(GTK_OBJECT(grab), "clicked", GTK_SIGNAL_FUNC((type == SUBFRAME_POSITION) ?
-									evt_pos_grab_clicked : evt_size_grab_clicked), win);
+		gtk_signal_connect(GTK_OBJECT(grab), "clicked", type == SUBFRAME_POSITION ?
+								GTK_SIGNAL_FUNC(evt_pos_grab_clicked) :
+								GTK_SIGNAL_FUNC(evt_size_grab_clicked), win);
 		gtk_table_attach(GTK_TABLE(table), grab, 2, 3, 0, 2,  0,0,0,0);
 	}
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
@@ -265,7 +266,6 @@ GtkWidget * win_wininfo_build(const WinInfo *wi, gboolean *modified)
 		gtk_container_add(GTK_CONTAINER(frame), hbox);
 		gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 5);
 	}
-
 	return vbox;
 }
 
@@ -297,7 +297,7 @@ void win_wininfo_save(const WinInfo *wi, FILE *out)
 	xml_put_node_close(out, "Windows");
 }
 
-static void window_load(XmlNode *window, gpointer user)
+static void window_load(const XmlNode *window, gpointer user)
 {
 	guint32	id;
 
@@ -320,7 +320,7 @@ static void window_load(XmlNode *window, gpointer user)
 }
 
 /* 2000-02-24 -	Fill in <wi> with details for windows, loaded from <node>. */
-void win_wininfo_load(WinInfo *wi, XmlNode *node)
+void win_wininfo_load(WinInfo *wi, const XmlNode *node)
 {
 	xml_node_visit_children(node, window_load, wi);
 }
@@ -547,6 +547,8 @@ GtkWidget * win_window_open(const WinInfo *wi, guint32 id)
 		if(!wd->pos_use)
 			gtk_window_set_position(GTK_WINDOW(wid), GTK_WIN_POS_MOUSE);
 		gtk_widget_realize(wid);
+		if(wi->min->gui != NULL && wi->min->gui->window != NULL)
+			gdk_window_set_group(wid->window, wi->min->gui->window->window);
 		return wid;
 	}
 	return NULL;
