@@ -118,9 +118,9 @@ static int put_string(FILE *out, const char *str);
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-07-27 -	Open a file for output, and insert any output XML to it. Then return the
-**		file pointer, so the user can use it in further calls to this module, thus
-**		storing various nodes and leafs. When done, the user should call xml_put_close().
+/* 1998-07-27 -	Open a file for output, and write any required XML header to it. Then return the
+**		file pointer, so the user can use it in further calls to this module, in order to
+**		store various nodes and leafs. When done, the user should call xml_put_close().
 **		BUG	Calls to xml_put_open() and xml_put_close() don't nest!! Sue me!
 */
 FILE * xml_put_open(const gchar *name)
@@ -130,7 +130,7 @@ FILE * xml_put_open(const gchar *name)
 	if((out = fopen(name, "wt")) != NULL)
 	{
 		fprintf(out, "<?xml version=\"1.0\" standalone=\"yes\"?>\n\n");
-		put_level = 0;
+		put_level = 0;	/* The reason we don't nest. */
 	}
 	return out;
 }
@@ -261,9 +261,9 @@ static int put_string(FILE *out, const gchar *str)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-01-30 -	Find a child of <node> named <name>, having a value of type <type>. */
-static XmlNode * get_node(XmlNode *node, const gchar *name, XVType type)
+static const XmlNode * get_node(const XmlNode *node, const gchar *name, XVType type)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if(node == NULL || name == NULL)
 		return NULL;
@@ -277,9 +277,9 @@ static XmlNode * get_node(XmlNode *node, const gchar *name, XVType type)
 **		steps fail, return 0. Can be called with <n> == NULL to check for the presence
 **		of a correctly typed and named value.
 */
-gboolean xml_get_integer(XmlNode *node, const gchar *name, int *n)
+gboolean xml_get_integer(const XmlNode *node, const gchar *name, int *n)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_INTEGER)) != NULL)
 	{
@@ -290,9 +290,9 @@ gboolean xml_get_integer(XmlNode *node, const gchar *name, int *n)
 	return FALSE;
 }
 
-gboolean xml_get_uinteger(XmlNode *node, const gchar *name, guint *n)
+gboolean xml_get_uinteger(const XmlNode *node, const gchar *name, guint *n)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_UINTEGER)) != NULL)
 	{
@@ -306,9 +306,9 @@ gboolean xml_get_uinteger(XmlNode *node, const gchar *name, guint *n)
 /* 1998-12-25 -	Search through <node>'s children for a real-valued node named <name>, and store
 **		the number in question at <x>. Returns 1 if value was found, 0 otherwise.
 */
-gboolean xml_get_real(XmlNode *node, const gchar *name, float *x)
+gboolean xml_get_real(const XmlNode *node, const gchar *name, float *x)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_REAL)) != NULL)
 	{
@@ -322,9 +322,9 @@ gboolean xml_get_real(XmlNode *node, const gchar *name, float *x)
 /* 1998-12-25 -	Search <node>'s kids for a boolean value named <name>. Returns 1 if the named
 **		value was indeed found (storing it in <x> if it's non-NULL), 0 otherwise.
 */
-gboolean xml_get_boolean(XmlNode *node, const gchar *name, gboolean *x)
+gboolean xml_get_boolean(const XmlNode *node, const gchar *name, gboolean *x)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_BOOL)) != NULL)
 	{
@@ -339,9 +339,9 @@ gboolean xml_get_boolean(XmlNode *node, const gchar *name, gboolean *x)
 **		text. If found, return 1 while storing a pointer to the text at <str>
 **		(if non-NULL). Otherwise returns 0.
 */
-gboolean xml_get_text(XmlNode *node, const gchar *name, gchar **str)
+gboolean xml_get_text(const XmlNode *node, const gchar *name, const gchar **str)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_TEXT)) != NULL)
 	{
@@ -352,9 +352,9 @@ gboolean xml_get_text(XmlNode *node, const gchar *name, gchar **str)
 	return FALSE;
 }
 
-gboolean xml_get_color(XmlNode *node, const gchar *name, GdkColor *col)
+gboolean xml_get_color(const XmlNode *node, const gchar *name, GdkColor *col)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_COLOR)) != NULL)
 	{
@@ -369,9 +369,9 @@ gboolean xml_get_color(XmlNode *node, const gchar *name, GdkColor *col)
 **		contains text. If found, and <str> is non-NULL, copy the text there,
 **		using no more than <max> characters. Returns 1 on success, or 0.
 */
-gboolean xml_get_text_copy(XmlNode *node, const gchar *name, gchar *str, gsize max)
+gboolean xml_get_text_copy(const XmlNode *node, const gchar *name, gchar *str, gsize max)
 {
-	XmlNode	*data;
+	const XmlNode	*data;
 
 	if((data = get_node(node, name, XVT_TEXT)) != NULL)
 	{
@@ -483,7 +483,7 @@ XmlNode * xml_node_new(const gchar *name)
 /* 1998-12-25 -	Check if the given node is called <name>. If so, return 1.
 **		Otherwise return 0.
 */
-gint xml_node_has_name(XmlNode *node, const gchar *name)
+gint xml_node_has_name(const XmlNode *node, const gchar *name)
 {
 	if(node != NULL && name != NULL)
 		return strcmp(node->name, name) == 0;
@@ -505,7 +505,7 @@ void xml_node_add_child(XmlNode *node, XmlNode *child)
 **		to use different callback functions for different nodes.
 ** 1999-01-04 -	This too used the old bad way of using glib's list functions. Fixed.
 */
-void xml_node_visit_children(XmlNode *node, void (*func)(XmlNode *child, gpointer user_data), gpointer user_data)
+void xml_node_visit_children(const XmlNode *node, void (*func)(const XmlNode *child, gpointer user_data), gpointer user_data)
 {
 	GSList	*iter;
 
@@ -782,9 +782,8 @@ void xml_tree_destroy(XmlNode *node)
 /* ----------------------------------------------------------------------------------------- */
 
 #if 0		/* xml_tree_print() */
-
 /* 1998-07-27 -	Prints an outline of a tree. Quite handy when debugging. */
-void xml_tree_print(XmlNode *root, gpointer data)
+void xml_tree_print(const XmlNode *root, gpointer data)
 {
 	int	i, level = (int) data;
 
@@ -822,7 +821,6 @@ void xml_tree_print(XmlNode *root, gpointer data)
 		g_slist_foreach(root->children, (GFunc) xml_tree_print, (gpointer) (level + 1));
 	}
 }
-
 #endif
 
 /* ----------------------------------------------------------------------------------------- */
@@ -830,10 +828,10 @@ void xml_tree_print(XmlNode *root, gpointer data)
 /* 1998-07-26 -	Find a node named <name>, and return a pointer to it. If no such node exists,
 **		we return NULL. Recurses througn entire tree.
 */
-XmlNode * xml_tree_search(XmlNode *root, const gchar *name)
+const XmlNode * xml_tree_search(const XmlNode *root, const gchar *name)
 {
-	GSList	*iter;
-	XmlNode	*node;
+	GSList		*iter;
+	const XmlNode	*node;
 
 	if(root != NULL)
 	{
